@@ -87,8 +87,13 @@ function user_block_land()
 
 end
 
+function user_map_square_blown_up(x,y)
+    column_down(x,y)
+end
+
 -- other functions -----------------------------------------------------------
 
 function user_map_time_callback()
     u61_map_add_score(1)
 end
+
