@@ -10,7 +10,7 @@ function delete_line(y_line)
     width=u61_map_get_width()
     x=0
     while x<width do
-        column_down(x,y_line)
+        u61_map_blow_up_square(x,y_line)
         x=x+1
     end
 end
@@ -35,6 +35,9 @@ function match_line(match_count)
             if u61_map_get_square_color(x,y)<0 then
                 holes=holes+1
             end
+            if not (u61_map_is_square_exploding(x,y)==0) then
+                holes=holes+1
+            end
             x=x+1
         end
         if holes==0 then 
