@@ -38,6 +38,9 @@
 
 #include "application.h"
 #include "global.h" 
+#include "version.h" 
+
+#include <stdio.h> 
 
 /*---------------------------------------------------------------------------
  globals
@@ -55,7 +58,14 @@ U61_Application application;
  */ 
 char *U61_Application::get_title()
 {
-	return "U61 0.1.3 by U-Foot (ufoot@ufoot.org / www.ufoot.org)";
+  char buf[U61_STRING_SIZE];        
+    
+  U61_Version::get_version_text(buf);
+  sprintf(app_name,
+	  "U61 %s by U-Foot (ufoot@ufoot.org / www.ufoot.org)",
+	  buf);
+
+  return app_name; 
 }
 
 /*--------------------------------------------------------------------------*/
@@ -64,13 +74,13 @@ char *U61_Application::get_title()
  */
 int U61_Application::main(int /*argc*/, char** /*argv*/)
 {
-    if (U61_Global::game.init())
+  if (U61_Global::game.init())
     {
-        U61_Global::game.run();
+      U61_Global::game.run();
     }
-    U61_Global::game.deinit();
+  U61_Global::game.deinit();
 
-    return 0;
+  return 0;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -79,9 +89,10 @@ int U61_Application::main(int /*argc*/, char** /*argv*/)
  */
 void U61_Application::init_modules()
 {
-    CL_SetupCore::init();
-    CL_SetupCore::init_display();
-    CL_SetupCore::init_sound();
+  CL_SetupCore::init();
+  CL_SetupCore::init_display();
+  CL_SetupCore::init_sound();
+  CL_SetupCore::init_network();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -90,7 +101,8 @@ void U61_Application::init_modules()
  */
 void U61_Application::deinit_modules()
 {
-    CL_SetupCore::deinit_sound();
-    CL_SetupCore::deinit_display();
-    CL_SetupCore::deinit();
+  CL_SetupCore::deinit_network();    
+  CL_SetupCore::deinit_sound();
+  CL_SetupCore::deinit_display();
+  CL_SetupCore::deinit();
 }
