@@ -363,6 +363,36 @@ void U61_Block::center()
     }
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * moves the block so that the top-left square has 0,0 coordinates
+ * used before drawing the preview block
+ */
+void U61_Block::corner()
+{
+    int i;
+    int x_min;
+    int y_min;
+
+    if (nb_items>0)
+    {
+        x_min=items[0].get_x();
+        y_min=items[0].get_y();
+
+        for (i=1;i<nb_items;++i)
+        {
+            x_min=min(x_min,items[i].get_x());
+            y_min=min(y_min,items[i].get_y());
+        }
+        
+        for (i=0;i<nb_items;++i)
+        {
+            items[i].set_x(items[i].get_x()-x_min);
+            items[i].set_y(items[i].get_y()-y_min);
+        }
+    }
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * draws a block onto the screen
