@@ -111,6 +111,10 @@ void U61_Config::reset()
     launch_count=read_int(ID_LAUNCH_COUNT,0);
     read_str(data_file,ID_DATA_FILE,"classic.dat");
     read_str(script_file,ID_SCRIPT_FILE,"classic.lua");
+
+    read_str(server_id,ID_SERVER_ID,"127.0.0.1");
+    network_port=read_int(ID_NETWORK_PORT,8061);
+    network_channel=read_int(ID_NETWORK_CHANNEL,1);
         
     initial_speed=read_int(ID_INITIAL_SPEED,5);
     acceleration=read_int(ID_ACCELERATION,5);
@@ -118,6 +122,8 @@ void U61_Config::reset()
     sound_volume=read_int(ID_SOUND_VOLUME,10);
     music_volume=read_int(ID_MUSIC_VOLUME,10);
 
+    max_fps=read_int(ID_MAX_FPS,18);
+
     for (pl=0;pl<NB_PLAYERS;++pl)
     {
         player[pl].first_repeat_move=read_player_int(pl,
@@ -270,12 +276,18 @@ bool U61_Config::write()
     ok=ok && write_str(file,ID_DATA_FILE, data_file);
     ok=ok && write_str(file,ID_SCRIPT_FILE, script_file);
 
+    ok=ok && write_str(file,ID_SERVER_ID, server_id);
+    ok=ok && write_int(file,ID_NETWORK_PORT, network_port);
+    ok=ok && write_int(file,ID_NETWORK_CHANNEL, network_channel);
+
     ok=ok && write_int(file,ID_INITIAL_SPEED, initial_speed);
     ok=ok && write_int(file,ID_ACCELERATION, acceleration);
 
     ok=ok && write_int(file,ID_SOUND_VOLUME, sound_volume);
     ok=ok && write_int(file,ID_MUSIC_VOLUME, music_volume);
 
+    ok=ok && write_int(file,ID_MAX_FPS, max_fps);
+
     for (pl=0;pl<NB_PLAYERS;++pl)
     {
         ok=ok && write_player_int(pl,file,ID_FIRST_REPEAT_MOVE,
