@@ -58,74 +58,87 @@
 
 class U61_Config
 {
-public:
-    U61_Config();
-    ~U61_Config();
+ public:
+  U61_Config();
+  ~U61_Config();
 
-    void reset();
-    bool read();
-    bool write();
-    bool load_script();
+  void reset();
+  bool read();
+  bool write();
+  bool load_script();
 
-    static const int NB_PLAYERS=4;
+  static const int NB_PLAYERS=4;
 
-    int launch_count;
+  int launch_count;
 
-    char data_file[U61_STRING_SIZE];
-    char script_file[U61_STRING_SIZE];
+  char data_file[U61_STRING_SIZE];
+  char script_file[U61_STRING_SIZE];
 
-    int initial_speed;
-    int acceleration;
-
-    int sound_volume;
-    int music_volume;
-
-    U61_PlayerConfig player[NB_PLAYERS];
-protected:
-    void read_str(char *buf,char *name,char *def);
-    int read_int(char *name,int def);
-    bool write_str(FILE *file,char *name, char *value); 
-    bool write_int(FILE *file,char *name,int value);
-    void read_player_str(char *buf,int pl,char *name,char *def);
-    int read_player_int(int pl,char *name,int def);
-    bool write_player_str(int pl,FILE *file,char *name, char *value); 
-    bool write_player_int(int pl,FILE *file,char *name,int value);
+  char server_id[U61_STRING_SIZE];
+  int network_port;
+  int network_channel;
     
-    static const int DUMMY_VALUE=1001;
-    static char *const ID_DUMMY="cfg_dummy";
-    static char *const ID_PLAYER="cfg_player_%d_";
+  int initial_speed;
+  int acceleration;
 
-    static char *const ID_LAUNCH_COUNT="cfg_launch_count";
-    static char *const ID_DATA_FILE="cfg_data_file";
-    static char *const ID_SCRIPT_FILE="cfg_script_file";
+  int sound_volume;
+  int music_volume;
 
-    static char *const ID_INITIAL_SPEED="cfg_initial_speed";
-    static char *const ID_ACCELERATION="cfg_acceleration";
+  int max_fps;
 
-    static char *const ID_SOUND_VOLUME="cfg_sound_volume";
-    static char *const ID_MUSIC_VOLUME="cfg_music_volume";
+  U61_PlayerConfig player[NB_PLAYERS];
 
-    static char *const ID_FIRST_REPEAT_MOVE="first_repeat_move";
-    static char *const ID_STANDARD_REPEAT_MOVE="standard_repeat_move";
-    static char *const ID_FIRST_REPEAT_ROTATE="first_repeat_rotate";
-    static char *const ID_STANDARD_REPEAT_ROTATE="standard_repeat_rotate";
-    static char *const ID_FIRST_REPEAT_OTHER="first_repeat_other";
-    static char *const ID_STANDARD_REPEAT_OTHER="standard_repeat_other";
+ protected:
+  void read_str(char *buf,char *name,char *def);
+  int read_int(char *name,int def);
+  bool write_str(FILE *file,char *name, char *value); 
+  bool write_int(FILE *file,char *name,int value);
+  void read_player_str(char *buf,int pl,char *name,char *def);
+  int read_player_int(int pl,char *name,int def);
+  bool write_player_str(int pl,FILE *file,char *name, char *value); 
+  bool write_player_int(int pl,FILE *file,char *name,int value);
+    
+  static const int DUMMY_VALUE=1001;
+  static char *const ID_DUMMY="cfg_dummy";
+  static char *const ID_PLAYER="cfg_player_%d_";
 
-    static char *const ID_PREVISION="prevision";
-    static char *const ID_ACTIVABLE="playing";
-    static char *const ID_NAME="name";
+  static char *const ID_LAUNCH_COUNT="cfg_launch_count";
+  static char *const ID_DATA_FILE="cfg_data_file";
+  static char *const ID_SCRIPT_FILE="cfg_script_file";
 
-    static char *const ID_KEY_START_STOP="key_start_stop";
-    static char *const ID_KEY_MOVE_LEFT="key_move_left";
-    static char *const ID_KEY_MOVE_RIGHT="key_move_right";
-    static char *const ID_KEY_ROTATE_LEFT="key_rotate_left";
-    static char *const ID_KEY_ROTATE_RIGHT="key_rotate_right";
-    static char *const ID_KEY_MOVE_DOWN="key_move_down";
-    static char *const ID_KEY_DROP="key_drop";
-    static char *const ID_KEY_NEXT_VICTIM="key_next_victim";
-    static char *const ID_KEY_PREV_VICTIM="key_prev_victim";
-    static char *const ID_KEY_USE_ANTEDOTE="key_use_antedote";
+  static char *const ID_SERVER_ID="cfg_server_id";
+  static char *const ID_NETWORK_PORT="cfg_network_port";
+  static char *const ID_NETWORK_CHANNEL="cfg_network_channel";
+
+  static char *const ID_INITIAL_SPEED="cfg_initial_speed";
+  static char *const ID_ACCELERATION="cfg_acceleration";
+
+  static char *const ID_SOUND_VOLUME="cfg_sound_volume";
+  static char *const ID_MUSIC_VOLUME="cfg_music_volume";
+
+  static char *const ID_MAX_FPS="cfg_max_fps";
+
+  static char *const ID_FIRST_REPEAT_MOVE="first_repeat_move";
+  static char *const ID_STANDARD_REPEAT_MOVE="standard_repeat_move";
+  static char *const ID_FIRST_REPEAT_ROTATE="first_repeat_rotate";
+  static char *const ID_STANDARD_REPEAT_ROTATE="standard_repeat_rotate";
+  static char *const ID_FIRST_REPEAT_OTHER="first_repeat_other";
+  static char *const ID_STANDARD_REPEAT_OTHER="standard_repeat_other";
+
+  static char *const ID_PREVISION="prevision";
+  static char *const ID_ACTIVABLE="playing";
+  static char *const ID_NAME="name";
+
+  static char *const ID_KEY_START_STOP="key_start_stop";
+  static char *const ID_KEY_MOVE_LEFT="key_move_left";
+  static char *const ID_KEY_MOVE_RIGHT="key_move_right";
+  static char *const ID_KEY_ROTATE_LEFT="key_rotate_left";
+  static char *const ID_KEY_ROTATE_RIGHT="key_rotate_right";
+  static char *const ID_KEY_MOVE_DOWN="key_move_down";
+  static char *const ID_KEY_DROP="key_drop";
+  static char *const ID_KEY_NEXT_VICTIM="key_next_victim";
+  static char *const ID_KEY_PREV_VICTIM="key_prev_victim";
+  static char *const ID_KEY_USE_ANTEDOTE="key_use_antedote";
 };
 
 #endif
