@@ -414,6 +414,18 @@ bool U61_Data::load_squares()
     prevision[SIZE_BIG]=CL_Surface::load(id,manager);
     success=success && (prevision[SIZE_BIG]!=NULL);
 
+    strcpy(id,ID_SQUARE_SMALL);
+    id[strlen(id)-1]=0;
+    strcat(id,ID_SQUARE_EXPLOSION);
+    explosion[SIZE_SMALL]=CL_Surface::load(id,manager);
+    success=success && (explosion[SIZE_SMALL]!=NULL);
+
+    strcpy(id,ID_SQUARE_BIG);
+    id[strlen(id)-1]=0;
+    strcat(id,ID_SQUARE_EXPLOSION);
+    explosion[SIZE_BIG]=CL_Surface::load(id,manager);
+    success=success && (explosion[SIZE_BIG]!=NULL);
+
     if (!success)
     {
         cout<<"Square loading failed\n";
