@@ -107,6 +107,7 @@ public:
     CL_Surface *curse_bg[NB_SIZE];
     CL_Surface *curse_fg[NB_SIZE];
     CL_Surface *prevision[NB_SIZE];
+    CL_Surface *explosion[NB_SIZE];
 
     CL_Surface *map[NB_MAP_MAX][NB_SIZE];
 
@@ -188,6 +189,7 @@ protected:
     static char *const ID_SQUARE_CURSE_FG="curse_fg";
     static char *const ID_SQUARE_CURSE_BG="curse_bg";
     static char *const ID_SQUARE_PREVISION="prevision";
+    static char *const ID_SQUARE_EXPLOSION="explosion";
 
     static char *const ID_MAP_BIG="map/big_n";
     static char *const ID_MAP_SMALL="map/small_n";
