@@ -54,6 +54,11 @@
 #include "global.h"
 #include "platform.h"
 #include "keychoose.h"
+#include "clientprotocol.h"
+#include "serverprotocol.h"
+#include "clientdispatcher.h"
+#include "serverdispatcher.h"
+#include "localdispatcher.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -70,7 +75,7 @@
  */ 
 U61_Game::U61_Game()
 {
-//    cout<< "U61 game object created\n";
+  //    cout<< "U61 game object created\n";
 }
 
 /*--------------------------------------------------------------------------*/
@@ -79,7 +84,7 @@ U61_Game::U61_Game()
  */ 
 U61_Game::~U61_Game()
 {
-//    cout << "Display : " <<  calls_to_display << " Logic : " << calls_to_logic << " Menu : " << calls_to_menu << " Poll : " << calls_to_poll << " Poll CL : " << calls_to_poll_clanlib << " Poll U61 : " << calls_to_poll_u61 << "\n";
+  //    cout << "Display : " <<  calls_to_display << " Logic : " << calls_to_logic << " Menu : " << calls_to_menu << " Poll : " << calls_to_poll << " Poll CL : " << calls_to_poll_clanlib << " Poll U61 : " << calls_to_poll_u61 << "\n";
 }
 
 /*--------------------------------------------------------------------------*/
@@ -91,42 +96,45 @@ U61_Game::~U61_Game()
  */
 bool U61_Game::init()
 {
-    bool success=true;
+  bool success=true;
     
-    calls_to_poll=0;
-    calls_to_poll_clanlib=0;
-    calls_to_poll_u61=0;
-    calls_to_poll_menu=0;
-    calls_to_display=0;
-    calls_to_menu=0;
-    calls_to_logic=0;
+  calls_to_poll=0;
+  calls_to_poll_clanlib=0;
+  calls_to_poll_u61=0;
+  calls_to_poll_menu=0;
+  calls_to_display=0;
+  calls_to_menu=0;
+  calls_to_logic=0;
 
-    U61_Global::config.read();
+  protocol=NULL;
+  dispatcher=NULL;
+
+  U61_Global::config.read();
     
-    U61_Script::init();
+  U61_Script::init();
 
-    if (success)
+  if (success)
     {
-        success=success && U61_Global::data.load1
-               (U61_Global::config.data_file);
+      success=success && U61_Global::data.load1
+	(U61_Global::config.data_file);
     }
 
-    if (success)
+  if (success)
     {
-        //cout<<"Trying video mode\n";
-        CL_Display::set_videomode(U61_Global::data.screen_w,
-                                  U61_Global::data.screen_h,16,false);
+      //cout<<"Trying video mode\n";
+      CL_Display::set_videomode(U61_Global::data.screen_w,
+				U61_Global::data.screen_h,16,false);
     }
 
-    if (success)
+  if (success)
     {
-        success=success && U61_Global::data.load2();
+      success=success && U61_Global::data.load2();
     }  
 
-    //cout<<"Setting video mode\n";
-    //CL_Display::set_videomode(640,480,16,false);
+  //cout<<"Setting video mode\n";
+  //CL_Display::set_videomode(640,480,16,false);
 
-    return success;
+  return success;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -136,8 +144,8 @@ bool U61_Game::init()
 void U61_Game::deinit()
 {
 
-    U61_Global::config.write();
-    U61_Global::data.unload();
+  U61_Global::config.write();
+  U61_Global::data.unload();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -148,86 +156,98 @@ void U61_Game::deinit()
  */
 void U61_Game::run()
 {
-    int done_for_this_display;
-    U61_Menu *exit_menu;
+  int done_for_this_display;
+  U61_Menu *exit_menu;
 
-    state=STATE_RUN;
+  state=STATE_RUN;
     
-    bind_keys();
-    reset_players();
+  bind_keys();
+  reset_players();
 
-    /*
-     * we set all the time parameters to default values
-     * these may be changed afterwards for real play but they
-     * still need to be set for the game not to crash...
-     */
-    U61_Time::reset();
-    last_clanlib_time_polled=CL_System::get_time();
-    last_menu_time_polled=CL_System::get_time();
-    last_u61_time_polled=U61_Time::for_event();
+  /*
+   * we set all the time parameters to default values
+   * these may be changed afterwards for real play but they
+   * still need to be set for the game not to crash...
+   */
+  U61_Time::reset();
+  last_clanlib_time_polled=CL_System::get_time();
+  last_menu_time_polled=CL_System::get_time();
+  last_u61_time_polled=U61_Time::for_event();
 
-    /*
-     * we have to set this so that the keychoose item works
-     */
-    U61_KeyChoose::register_key_map(&menu_input);
+  /*
+   * we have to set this so that the keychoose item works
+   */
+  U61_KeyChoose::register_key_map(&menu_input);
 
-    /*
-     * the game starts on the main menu, which has the exit menu as
-     * a parent, logical, eh?
-     */
-    exit_menu=new U61_ExitMenu();
-    current_menu=new U61_MainMenu(exit_menu);
+  /*
+   * the game starts on the main menu, which has the exit menu as
+   * a parent, logical, eh?
+   */
+  exit_menu=new U61_ExitMenu();
+  current_menu=new U61_MainMenu(exit_menu);
 
-    /*
-     * Plays a startup sound
-     */
-    U61_Sound::play_game_start();
-    U61_Music::test();
+  /*
+   * Plays a startup sound
+   */
+  U61_Sound::play_game_start();
+  U61_Music::test();
 
-    /*
-     * main game loop
-     */
-    while (state==STATE_RUN) 
+  /*
+   * main game loop
+   */
+  while (state==STATE_RUN) 
     {
-        /*
-         * we perform calls to the logic function, but we don't
-         * call it more than "max_logic_per_display" times
-         * this way, the player will always have its screen
-         * updated, even if his computer is not fast enough
-         */
-        done_for_this_display=0;
-        while (U61_Time::is_logic_needed() 
-               && done_for_this_display < MAX_LOGIC_PER_DISPLAY)
+      /*
+       * we perform calls to the logic function, but we don't
+       * call it more than "max_logic_per_display" times
+       * this way, the player will always have its screen
+       * updated, even if his computer is not fast enough
+       */
+      done_for_this_display=0;
+      while (U61_Time::is_logic_needed() 
+	     && done_for_this_display < MAX_LOGIC_PER_DISPLAY)
         {
-            poll();
-            logic();
-            U61_Time::acknowledge_logic();
-            done_for_this_display++;
+	  poll();
+	  logic();
+	  U61_Time::acknowledge_logic();
+	  done_for_this_display++;
         }
 
-        /*
-         * if "max_logic_per_display" calls to logic have been
-         * done, it means the computer is slow, therefore, we
-         * force the computer to slow down the game, since it's
-         * not powerfull enough to run it at full speed
-         */
-        if (done_for_this_display>=MAX_LOGIC_PER_DISPLAY)
+      /*
+       * if "max_logic_per_display" calls to logic have been
+       * done, it means the computer is slow, therefore, we
+       * force the computer to slow down the game, since it's
+       * not powerfull enough to run it at full speed
+       */
+      if (done_for_this_display>=MAX_LOGIC_PER_DISPLAY)
         {
           /*  while (U61_Time::is_logic_needed())
-            {
-                U61_Time::slow_down();
-            }*/
+	      {
+	      U61_Time::slow_down();
+	      }*/
         }
 
-        /*
-         * call the display, menu and flip fonctions once per loop
-         */
-        poll();
-        display();
-        poll();
-        menu();
-        poll();
-        CL_Display::flip_display(false);
+      /*
+       * call the display, menu and flip fonctions once per loop
+       */
+      poll();
+      while (!U61_Time::is_display_needed(U61_Global::config.max_fps))
+	{
+	  U61_Time::idle();
+	  poll();
+	}
+      U61_Time::acknowledge_display();
+      display();
+      poll();
+
+      if (protocol!=NULL)
+        {
+	  network();
+        }
+      poll();
+      menu();
+      poll();
+      CL_Display::flip_display(false);
     };
 }
 
@@ -237,7 +257,7 @@ void U61_Game::run()
  */
 void U61_Game::quit()
 {
-    state=STATE_QUIT;
+  state=STATE_QUIT;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -247,52 +267,52 @@ void U61_Game::quit()
  */
 void U61_Game::poll()
 {
-    int i;
-    int clanlib_time;
-    int u61_time;
+  int i;
+  int clanlib_time;
+  int u61_time;
 
-    clanlib_time=CL_System::get_time();
-    if (last_clanlib_time_polled<clanlib_time)
+  clanlib_time=CL_System::get_time();
+  if (last_clanlib_time_polled<clanlib_time)
     {
-        /*
-         * required by ClanLib, polls the keyboard and does 
-         * some system low level stuff
-         */
-        CL_System::keep_alive();
-        last_clanlib_time_polled=clanlib_time;
-        calls_to_poll_clanlib++;
+      /*
+       * required by ClanLib, polls the keyboard and does 
+       * some system low level stuff
+       */
+      CL_System::keep_alive();
+      last_clanlib_time_polled=clanlib_time;
+      calls_to_poll_clanlib++;
 
-        u61_time=U61_Time::for_event();
-        /*
-         * this test disables useless polling
-         * polling is done at a maximum rate of 30 / sec
-         */
-        if (last_menu_time_polled<clanlib_time-MENU_POLL_DELAY)
+      u61_time=U61_Time::for_event();
+      /*
+       * this test disables useless polling
+       * polling is done at a maximum rate of 30 / sec
+       */
+      if (last_menu_time_polled<clanlib_time-MENU_POLL_DELAY)
         {
-            last_menu_time_polled=clanlib_time;   
+	  last_menu_time_polled=clanlib_time;   
 
-            menu_input.poll(u61_time);
+	  menu_input.poll(u61_time);
 
-            calls_to_poll_menu++;     
+	  calls_to_poll_menu++;     
         }
-        /*
-         * this test disables useless polling
-         * polling is done at a maximum rate of once per game cycle
-         */
-        if (last_u61_time_polled<u61_time)
+      /*
+       * this test disables useless polling
+       * polling is done at a maximum rate of once per game cycle
+       */
+      if (last_u61_time_polled<u61_time)
         {
-            last_u61_time_polled=u61_time;   
+	  last_u61_time_polled=u61_time;   
 
-            for (i=0;i<U61_Layout::NB_PLAYERS_LOCAL;++i)
+	  for (i=0;i<U61_Layout::NB_PLAYERS_LOCAL;++i)
             {
-                player_input[i].poll(u61_time);
+	      player_input[i].poll(u61_time);
             }
-            //cout<<"polled "<<ticks_now<<"\n";
+	  //cout<<"polled "<<ticks_now<<"\n";
 
-            calls_to_poll_u61++;     
+	  calls_to_poll_u61++;     
         }
     }
-    calls_to_poll++;
+  calls_to_poll++;
 }
  
 /*--------------------------------------------------------------------------*/
@@ -304,10 +324,10 @@ void U61_Game::poll()
  */ 
 void U61_Game::logic()
 {
-    pump_player_events();
+  pump_player_events();
 
-    //U61_Script::test();
-    calls_to_logic++;
+  //U61_Script::test();
+  calls_to_logic++;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -318,25 +338,25 @@ void U61_Game::logic()
  */ 
 void U61_Game::display()
 {
-    CL_Display::clear_display();
+  CL_Display::clear_display();
 
-    U61_Square::update_cycle();
-/*
+  U61_Square::update_cycle();
+  /*
     for (i=0;i<U61_Layout::NB_PLAYERS_TOTAL;++i)
     {
-        if (player[i].is_available())
-        {
-            player[i].draw(0,0);
-        }
-    }
- */   
-    layout.draw();
-    if (current_menu!=NULL)
+    if (player[i].is_available())
     {
-        current_menu->draw();
+    player[i].draw(0,0);
+    }
+    }
+  */   
+  layout.draw();
+  if (current_menu!=NULL)
+    {
+      current_menu->draw();
     }
 
-    calls_to_display++;  
+  calls_to_display++;  
 }
 
 /*--------------------------------------------------------------------------*/
@@ -346,32 +366,46 @@ void U61_Game::display()
  */
 void U61_Game::menu()
 {
-    U61_Menu *next_menu;
-    U61_Event key;
+  U61_Menu *next_menu;
+  U61_Event key;
 
-    next_menu=current_menu;
+  next_menu=current_menu;
 
-    if (!menu_input.empty())
+  if (!menu_input.empty())
     {
-        key=menu_input.get();
-        next_menu=current_menu->action(key.code);
+      key=menu_input.get();
+      next_menu=current_menu->action(key.code);
     }
 
-    if (next_menu==NULL)
+  if (next_menu==NULL)
     {
-        quit();
+      quit();
     }
-    else
+  else
     {
-        if (next_menu==current_menu->get_parent())
+      if (next_menu==current_menu->get_parent())
         {
-            delete current_menu;
+	  delete current_menu;
         }
 
-        current_menu=next_menu;
+      current_menu=next_menu;
     }
 
-    calls_to_menu++;
+  calls_to_menu++;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * calls the network code, on a regular basis
+ */
+void U61_Game::network()
+{
+  //cout<<"Network polled\n"; 
+  if (protocol->send_all()==U61_Protocol::FAILED 
+      || protocol->recv_all()==U61_Protocol::FAILED)
+    {
+      protocol->print_diagnostic();
+    }
 }
 
 /*--------------------------------------------------------------------------*/
@@ -391,10 +425,10 @@ void U61_Game::configure_cold()
  */
 void U61_Game::configure_hot()
 {
-    int i;
+  int i;
 
-    bind_keys();
-    for (i=0;i<U61_Layout::NB_PLAYERS_LOCAL;++i)
+  bind_keys();
+  for (i=0;i<U61_Layout::NB_PLAYERS_LOCAL;++i)
     {
     } 
 }
@@ -405,17 +439,19 @@ void U61_Game::configure_hot()
  */
 void U61_Game::start_quick()
 {
-    int num;
+  int num;
 
-    //cout<<"quick start\n";
-    if (standard_init())
+  //cout<<"quick start\n";
+  if (standard_init())
     {
-        num=get_local_player(0);
-        //cout<<"num="<<num<<"\n";
-        //cout<<"name="<<U61_Global::config.player[num].name<<"\n";
-        player[0].init_local(&(player_input[num]),0,
-            &(U61_Global::config.player[num]));
-        layout.init_alone(&(player[0]));
+      dispatcher=new U61_LocalDispatcher();
+
+      num=get_local_player(0);
+      //cout<<"num="<<num<<"\n";
+      //cout<<"name="<<U61_Global::config.player[num].name<<"\n";
+      player[0].init_local(&(player_input[num]),0,
+			   &(U61_Global::config.player[num]));
+      layout.init_alone(&(player[0]));
     }
 }
 
@@ -425,17 +461,19 @@ void U61_Game::start_quick()
  */
 void U61_Game::start_local_alone()
 {
-    int num;
+  int num;
 
-    //cout<<"local alone game started\n";
-    if (standard_init())
+  //cout<<"local alone game started\n";
+  if (standard_init())
     {
-        num=get_local_player(0);
-        //cout<<"num="<<num<<"\n";
-        //cout<<"name="<<U61_Global::config.player[num].name<<"\n";
-        player[0].init_local(&(player_input[num]),0,
-            &(U61_Global::config.player[num]));
-        layout.init_alone(&(player[0]));
+      dispatcher=new U61_LocalDispatcher();
+
+      num=get_local_player(0);
+      //cout<<"num="<<num<<"\n";
+      //cout<<"name="<<U61_Global::config.player[num].name<<"\n";
+      player[0].init_local(&(player_input[num]),0,
+			   &(U61_Global::config.player[num]));
+      layout.init_alone(&(player[0]));
     }
 }
 
@@ -445,51 +483,53 @@ void U61_Game::start_local_alone()
  */
 void U61_Game::start_local_multiplayer()
 {
-    int num0,num1,num2,num3;
-    //cout<<"local multiplayer game started\n";
-    if (standard_init())
+  int num0,num1,num2,num3;
+  //cout<<"local multiplayer game started\n";
+  if (standard_init())
     {
-        num0=get_local_player(0);
-        player[0].init_local(&(player_input[num0]),0,
-            &(U61_Global::config.player[num0]));
+      dispatcher=new U61_LocalDispatcher();
 
-        num1=get_local_player(1);
-        if (num1<0)
+      num0=get_local_player(0);
+      player[0].init_local(&(player_input[num0]),0,
+			   &(U61_Global::config.player[num0]));
+
+      num1=get_local_player(1);
+      if (num1<0)
         {
-            layout.init_alone(&(player[0]));
+	  layout.init_alone(&(player[0]));
         }
-        else
+      else
         {
-            player[1].init_local(&(player_input[num1]),0,
-                &(U61_Global::config.player[num1]));
+	  player[1].init_local(&(player_input[num1]),0,
+			       &(U61_Global::config.player[num1]));
 
-            num2=get_local_player(2);
-            if (num2<0)
+	  num2=get_local_player(2);
+	  if (num2<0)
             {
-                layout.init_multiplayer_2(&(player[0]),
-                                          &(player[1]));
+	      layout.init_multiplayer_2(&(player[0]),
+					&(player[1]));
             }
-            else
+	  else
             {
-                player[2].init_local(&(player_input[num2]),0,
-                    &(U61_Global::config.player[num2]));
+	      player[2].init_local(&(player_input[num2]),0,
+				   &(U61_Global::config.player[num2]));
                 
-                num3=get_local_player(3);
-                if (num3<0)
+	      num3=get_local_player(3);
+	      if (num3<0)
                 {
-                    layout.init_multiplayer_3(&(player[0]),
-                                              &(player[1]),
-                                              &(player[2]));
+		  layout.init_multiplayer_3(&(player[0]),
+					    &(player[1]),
+					    &(player[2]));
                 }
-                else
+	      else
                 {
-                    player[3].init_local(&(player_input[num3]),0,
-                        &(U61_Global::config.player[num3]));
+		  player[3].init_local(&(player_input[num3]),0,
+				       &(U61_Global::config.player[num3]));
                     
-                    layout.init_multiplayer_4(&(player[0]),
-                                              &(player[1]),
-                                              &(player[2]),
-                                              &(player[3]));
+		  layout.init_multiplayer_4(&(player[0]),
+					    &(player[1]),
+					    &(player[2]),
+					    &(player[3]));
                 }
             }
         }
@@ -502,9 +542,16 @@ void U61_Game::start_local_multiplayer()
  */
 void U61_Game::start_network_new()
 {
-    //cout<<"new network game started\n";
-    if (standard_init())
+  U61_ServerDispatcher *d;
+
+  //cout<<"new network game started\n";
+  if (standard_init())
     {
+      d=new U61_ServerDispatcher();
+      dispatcher=d;
+      protocol=new U61_ServerProtocol(d,
+				      U61_Global::config.network_port,
+                                      U61_Global::config.network_channel);
     }
 }
 
@@ -514,9 +561,35 @@ void U61_Game::start_network_new()
  */
 void U61_Game::start_network_join()
 {
-    //cout<<"joining network game\n";
-    if (standard_init())
+  U61_ClientDispatcher *d;
+
+  //cout<<"joining network game\n";
+  if (standard_init())
     {
+      d=new U61_ClientDispatcher();
+      dispatcher=d;
+      protocol=new U61_ClientProtocol(d,
+				      U61_Global::config.network_port,
+                                      U61_Global::config.network_channel,
+				      U61_Global::config.server_id);
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * stops all network activity
+ */
+void U61_Game::stop_network()
+{
+  if (protocol!=NULL)
+    {
+      delete protocol;
+      protocol=NULL;
+    }
+  if (dispatcher!=NULL)
+    {
+      delete dispatcher;
+      dispatcher=NULL;
     }
 }
 
@@ -526,8 +599,10 @@ void U61_Game::start_network_join()
  */
 void U61_Game::stop()
 {
-    reset_players();
-    layout.reset();
+  reset_players();
+  layout.reset();
+  stop_network();
+  //cout<<"game stopped\n";
 }
 
 /*--------------------------------------------------------------------------*/
@@ -536,18 +611,18 @@ void U61_Game::stop()
  */
 bool U61_Game::standard_init()
 {
-    bool ok=true;
+  bool ok=true;
 
-    configure_cold();
-    configure_hot();
+  configure_cold();
+  configure_hot();
 
-    time_reset();
+  time_reset();
 
-    stop();
+  stop();
 
-    ok=ok && U61_Global::config.load_script();
+  ok=ok && U61_Global::config.load_script();
     
-    return ok;
+  return ok;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -556,14 +631,14 @@ bool U61_Game::standard_init()
  */
 void U61_Game::time_reset(int time)
 {
-    int i;
+  int i;
 
-    U61_Time::reset(time);
-    last_u61_time_polled=time;
-    menu_input.reset();
-    for (i=0;i<U61_Layout::NB_PLAYERS_LOCAL;++i)
+  U61_Time::reset(time);
+  last_u61_time_polled=time;
+  menu_input.reset();
+  for (i=0;i<U61_Layout::NB_PLAYERS_LOCAL;++i)
     {
-        player_input[i].reset();
+      player_input[i].reset();
     }    
 }
 
@@ -574,11 +649,11 @@ void U61_Game::time_reset(int time)
  */
 void U61_Game::bind_keys()
 {
-    int i;
+  int i;
 
-    for (i=0;i<U61_Layout::NB_PLAYERS_LOCAL && i<U61_Config::NB_PLAYERS;++i)
+  for (i=0;i<U61_Layout::NB_PLAYERS_LOCAL && i<U61_Config::NB_PLAYERS;++i)
     {
-        player_input[i].init(&(U61_Global::config.player[i]));
+      player_input[i].init(&(U61_Global::config.player[i]));
     }
 } 
 
@@ -588,12 +663,12 @@ void U61_Game::bind_keys()
  */
 void U61_Game::reset_players()
 {
-    int i;
+  int i;
 
-    for (i=0;i<U61_Layout::NB_PLAYERS_TOTAL;++i)
+  for (i=0;i<U61_Layout::NB_PLAYERS_TOTAL;++i)
     {
-        player[i].reset();
-        player[i].set_id(i);
+      player[i].reset();
+      player[i].set_id(i);
     }
 } 
 
@@ -604,13 +679,13 @@ void U61_Game::reset_players()
  */
 void U61_Game::pump_player_events()
 {
-    int i;
+  int i;
 
-    for (i=0;i<U61_Layout::NB_PLAYERS_TOTAL;++i)
+  for (i=0;i<U61_Layout::NB_PLAYERS_TOTAL;++i)
     {
-        if (player[i].is_available())
+      if (player[i].is_available())
         {
-            player[i].pump_events();
+	  player[i].pump_events();
         }
     }
 } 
@@ -624,26 +699,26 @@ void U61_Game::pump_player_events()
  */
 int U61_Game::get_local_player(int order)
 {
-    int result=-1;
-    int found=0;
-    int i;
+  int result=-1;
+  int found=0;
+  int i;
 
-    for (i=0;i<U61_Config::NB_PLAYERS;++i)
+  for (i=0;i<U61_Config::NB_PLAYERS;++i)
     {
-        if (U61_Global::config.player[i].activable)
+      if (U61_Global::config.player[i].activable)
         {
-            if (found==order)
+	  if (found==order)
             {
-                result=i;
+	      result=i;
             }
-            found++;
+	  found++;
         }
     }
-    if (order==0 && result<0)
+  if (order==0 && result<0)
     {
-        U61_Global::config.player[0].activable=true;
-        result=0;
+      U61_Global::config.player[0].activable=true;
+      result=0;
     }
 
-    return result;
+  return result;
 }
