@@ -56,6 +56,8 @@
 #include "config.h"
 #include "data.h"
 #include "player.h"
+#include "protocol.h"
+#include "dispatcher.h"
 
 /*---------------------------------------------------------------------------
  constants
@@ -93,8 +95,11 @@ protected:
     U61_PlayerInput player_input[U61_Layout::NB_PLAYERS_LOCAL]; 
     U61_Layout layout;
     U61_Player player[U61_Layout::NB_PLAYERS_TOTAL];
+    U61_Protocol *protocol;
+    U61_Dispatcher *dispatcher;
 
     bool standard_init();
+    void stop_network();
 
     void bind_keys();
     void reset_players();
@@ -106,6 +111,7 @@ protected:
     void display();
     void menu();
     void logic();
+    void network();
 
     U61_Menu *current_menu;
 
@@ -113,7 +119,7 @@ protected:
 
     int state;
 
-    static const int MAX_LOGIC_PER_DISPLAY=10;
+    static const int MAX_LOGIC_PER_DISPLAY=50;
     static const int MENU_POLL_DELAY=33;
 
     int last_clanlib_time_polled;
