@@ -96,7 +96,78 @@ void U61_Layout::init_alone(U61_Player *p)
                   U61_Global::data.screen_w/2,
                   U61_Global::data.screen_h/2,
                   U61_Data::SIZE_BIG);
-    //cout<<"layout initialized with "<<p->get_name()<<"\n";
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * inits the layout for 2 local multiplayer players
+ */
+void U61_Layout::init_multiplayer_2(U61_Player *p1,
+                                    U61_Player *p2)
+{
+    reset();
+
+    items[0].init(p1,
+                  (3*U61_Global::data.screen_w)/8,
+                  U61_Global::data.screen_h/2,
+                  U61_Data::SIZE_BIG);
+    items[1].init(p2,
+                  (5*U61_Global::data.screen_w)/8,
+                  U61_Global::data.screen_h/2,
+                  U61_Data::SIZE_BIG);
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * inits the layout for 3 local multiplayer players
+ */
+void U61_Layout::init_multiplayer_3(U61_Player *p1,
+                                    U61_Player *p2,
+                                    U61_Player *p3)
+{
+    reset();
+
+    items[0].init(p1,
+                  U61_Global::data.screen_w/4,
+                  U61_Global::data.screen_h/2,
+                  U61_Data::SIZE_BIG);
+    items[1].init(p2,
+                  U61_Global::data.screen_w/2,
+                  U61_Global::data.screen_h/2,
+                  U61_Data::SIZE_BIG);
+    items[2].init(p3,
+                  (3*U61_Global::data.screen_w)/4,
+                  U61_Global::data.screen_h/2,
+                  U61_Data::SIZE_BIG);
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * inits the layout for 4 local multiplayer players
+ */
+void U61_Layout::init_multiplayer_4(U61_Player *p1,
+                                    U61_Player *p2,
+                                    U61_Player *p3,
+                                    U61_Player *p4)
+{
+    reset();
+
+    items[0].init(p1,
+                  (1*U61_Global::data.screen_w)/8,
+                  U61_Global::data.screen_h/2,
+                  U61_Data::SIZE_BIG);
+    items[1].init(p2,
+                  (3*U61_Global::data.screen_w)/8,
+                  U61_Global::data.screen_h/2,
+                  U61_Data::SIZE_BIG);
+    items[2].init(p3,
+                  (5*U61_Global::data.screen_w)/8,
+                  U61_Global::data.screen_h/2,
+                  U61_Data::SIZE_BIG);
+    items[3].init(p4,
+                  (7*U61_Global::data.screen_w)/8,
+                  U61_Global::data.screen_h/2,
+                  U61_Data::SIZE_BIG);
 }
 
 /*--------------------------------------------------------------------------*/
