@@ -60,6 +60,15 @@ public:
     void reset();
 
     void init_alone(U61_Player *p);
+    void init_multiplayer_2(U61_Player *p1,
+                            U61_Player *p2);
+    void init_multiplayer_3(U61_Player *p1,
+                            U61_Player *p2,
+                            U61_Player *p3);
+    void init_multiplayer_4(U61_Player *p1,
+                            U61_Player *p2,
+                            U61_Player *p3,
+                            U61_Player *p4);
  
     void draw();
 
