@@ -147,11 +147,21 @@ void U61_LayoutItem::draw()
 
         U61_Global::data.info[size]->put_screen(x_info,y_info);
 
+        sprintf(buffer,"%s",player->get_name());
+        U61_Global::data.font_info[size]->print_left
+            (x_info+U61_Global::data.offset_name_x[size],
+             y_info+U61_Global::data.offset_name_y[size],
+             buffer);
+
         sprintf(buffer,"%d",player->get_score());
-        U61_Global::data.font_menu->print_left
-            (x_info+20,y_info+20,buffer);
-        player->get_next_block().draw_preview(x_center,y_info+60,size);
-//        U61_Global::data.font_menu->print_left
-//            (x_map,y_map,player->get_name());
+        U61_Global::data.font_info[size]->print_left
+            (x_info+U61_Global::data.offset_score_x[size],
+             y_info+U61_Global::data.offset_score_y[size],
+             buffer);
+
+        player->get_next_block().draw_preview
+            (x_info+U61_Global::data.offset_preview_x[size],
+             y_info+U61_Global::data.offset_preview_y[size],
+             size);
     }
 }
