@@ -74,10 +74,8 @@ protected:
     int y_center;
     int x_map;
     int y_map;
-    int x_map_bg;
-    int y_map_bg;
-    int x_info_bg;
-    int y_info_bg;
+    int x_info;
+    int y_info;
 
     void calc_coords();
 };
