@@ -61,19 +61,19 @@
  * have something more subtle than just a linear behavior
  */ 
 const int U61_Map::speeds[MAX_SYSTEM_SPEED+1]=
-    {
-       2,  5, 10, 15, 20, 30, 40, 50, 60, 70, 80,
-          85,90,95,100,105,110,115,120,125,130,
-         135,140,145,150,155,160,170,180,190,200,
-         210,220,230,240,250,260,270,280,290,300,
-         310,320,330,340,350,360,370,380,390,400
-    };
+{
+  2,  5, 10, 15, 20, 30, 40, 50, 60, 70, 80,
+  85,90,95,100,105,110,115,120,125,130,
+  135,140,145,150,155,160,170,180,190,200,
+  210,220,230,240,250,260,270,280,290,300,
+  310,320,330,340,350,360,370,380,390,400
+};
 const int U61_Map::accels[MAX_SYSTEM_ACCEL+1]=
-    {
-       0,  2,  5, 10, 15, 20,
-          30, 40, 60, 80,100,
-         120,140,160,180,200
-    };
+{
+  0,  2,  5, 10, 15, 20,
+  30, 40, 60, 80,100,
+  120,140,160,180,200
+};
 
 /*---------------------------------------------------------------------------
  functions
@@ -85,7 +85,7 @@ const int U61_Map::accels[MAX_SYSTEM_ACCEL+1]=
  */ 
 U61_Map::U61_Map()
 {
-    active=false;
+  active=false;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -103,15 +103,15 @@ U61_Map::~U61_Map()
  */
 void U61_Map::clear()
 {
-    int i,j;
+  int i,j;
 
-    for (j=0;j<HEIGHT;++j)
+  for (j=0;j<HEIGHT;++j)
     {
-        for (i=0;i<WIDTH;++i)
+      for (i=0;i<WIDTH;++i)
         {
-            squares[i][j].disable();
-            //squares[i][j].enable();
-            squares[i][j].set_color((i+j)%8);
+	  squares[i][j].disable();
+	  //squares[i][j].enable();
+	  squares[i][j].set_color((i+j)%8);
         }
     }
 }
@@ -123,34 +123,34 @@ void U61_Map::clear()
  */
 void U61_Map::begin()
 {
-    int i;
+  int i;
 
-    auto_events.clear();
+  auto_events.clear();
     
-    clear();
+  clear();
  
-    block.reset();
-    next_block.reset();
-    block_requested=false;
-    matching=false;
-    speed_counter=0;
-    accel_counter=0;
-    speed=base_speed;
-    accel=base_accel; 
-    background=0;
-    prevision_state=true;
-    preview_state=true;
-    match_count=0;
-    if (score>best_score)
+  block.reset();
+  next_block.reset();
+  block_requested=false;
+  matching=false;
+  speed_counter=0;
+  accel_counter=0;
+  speed=base_speed;
+  accel=base_accel; 
+  background=0;
+  prevision_state=true;
+  preview_state=true;
+  match_count=0;
+  if (score>best_score)
     {
-        best_score=score;
+      best_score=score;
     }
-    score=0;
-    for (i=0;i<NB_GLOBAL;++i)
+  score=0;
+  for (i=0;i<NB_GLOBAL;++i)
     {
-        global_val[i]=0;
+      global_val[i]=0;
     }        
-    //block.shape(0);
+  //block.shape(0);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -159,16 +159,16 @@ void U61_Map::begin()
  */
 void U61_Map::reset(int s,int a)
 {
-    map_time=0;
-    active=false;
-    best_score=0;
-    score=0;
-    games=0; 
-    base_speed=s;
-    base_accel=a;
-    silent=false;
+  map_time=0;
+  active=false;
+  best_score=0;
+  score=0;
+  games=0; 
+  base_speed=s;
+  base_accel=a;
+  silent=false;
 
-    begin();
+  begin();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -180,7 +180,7 @@ void U61_Map::reset(int s,int a)
  */
 bool U61_Map::is_active()
 {
-    return active;
+  return active;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -189,9 +189,9 @@ bool U61_Map::is_active()
  */
 void U61_Map::set_active(int time)
 {
-    //reset();
-    map_time=time;
-    active=true;
+  //reset();
+  map_time=time;
+  active=true;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -200,7 +200,7 @@ void U61_Map::set_active(int time)
  */
 void U61_Map::set_inactive()
 {
-    active=false;
+  active=false;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -209,15 +209,15 @@ void U61_Map::set_inactive()
  */
 void U61_Map::set_background(int bg)
 {
-    background=bg;
+  background=bg;
 
-    if (background<0)
+  if (background<0)
     {
-        background=0;
+      background=0;
     }
-    while (background>=U61_Global::data.nb_map)
+  while (background>=U61_Global::data.nb_map)
     {
-        background-=U61_Global::data.nb_map;
+      background-=U61_Global::data.nb_map;
     }
 }
 
@@ -227,7 +227,7 @@ void U61_Map::set_background(int bg)
  */
 int U61_Map::get_background()
 {
-    return background;
+  return background;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -239,16 +239,16 @@ int U61_Map::get_background()
  */
 void U61_Map::set_square_color(int x,int y,int color)
 {
-    if (x>=0 && y>=0 && x<WIDTH && y<HEIGHT)
+  if (x>=0 && y>=0 && x<WIDTH && y<HEIGHT)
     {
-        if (color>=0 && color<U61_Square::NB_COLORS)
+      if (color>=0 && color<U61_Square::NB_COLORS)
         {
-            squares[x][y].enable();
-            squares[x][y].set_color(color);
+	  squares[x][y].enable();
+	  squares[x][y].set_color(color);
         }
-        else
+      else
         {
-            squares[x][y].disable();
+	  squares[x][y].disable();
         }
     }
 }
@@ -262,16 +262,16 @@ void U61_Map::set_square_color(int x,int y,int color)
  */
 int U61_Map::get_square_color(int x,int y)
 {
-    int color=-1;
+  int color=-1;
 
-    if (x>=0 && y>=0 && x<WIDTH && y<HEIGHT)
+  if (x>=0 && y>=0 && x<WIDTH && y<HEIGHT)
     {
-        if (squares[x][y].is_enabled())
+      if (squares[x][y].is_enabled())
         {
-            color=squares[x][y].get_color();
+	  color=squares[x][y].get_color();
         }
     }
-    return color;
+  return color;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -280,13 +280,13 @@ int U61_Map::get_square_color(int x,int y)
  */
 void U61_Map::set_score(int s)
 {
-    if (s>=0)
+  if (s>=0)
     {
-        score=s;
+      score=s;
     }
-    else
+  else
     {
-        score=0;
+      score=0;
     }
 }
 
@@ -296,7 +296,7 @@ void U61_Map::set_score(int s)
  */
 int U61_Map::get_score()
 {
-    return score;
+  return score;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -305,7 +305,7 @@ int U61_Map::get_score()
  */
 int U61_Map::get_best_score()
 {
-    return best_score;
+  return best_score;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -314,10 +314,10 @@ int U61_Map::get_best_score()
  */
 void U61_Map::add_score(int s)
 {
-    score+=s;
-    if (score<0)
+  score+=s;
+  if (score<0)
     {
-        score=0;
+      score=0;
     }
 }
 
@@ -327,7 +327,7 @@ void U61_Map::add_score(int s)
  */
 int U61_Map::get_time()
 {
-    return map_time;
+  return map_time;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -336,7 +336,7 @@ int U61_Map::get_time()
  */
 int U61_Map::get_nb_games()
 {
-    return games;
+  return games;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -345,7 +345,7 @@ int U61_Map::get_nb_games()
  */
 int U61_Map::get_match_count()
 {
-    return match_count;
+  return match_count;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -355,9 +355,9 @@ int U61_Map::get_match_count()
  */
 void U61_Map::set_global(int i, int glob)
 {
-    if (i>=0 && i<NB_GLOBAL)
+  if (i>=0 && i<NB_GLOBAL)
     {
-        global_val[i]=glob;
+      global_val[i]=glob;
     }
 }
 
@@ -368,14 +368,14 @@ void U61_Map::set_global(int i, int glob)
  */
 int U61_Map::get_global(int i)
 {
-    int glob=0;
+  int glob=0;
 
-    if (i>=0 && i<NB_GLOBAL)
+  if (i>=0 && i<NB_GLOBAL)
     {
-        glob=global_val[i];
+      glob=global_val[i];
     }
 
-    return glob;
+  return glob;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -384,17 +384,20 @@ int U61_Map::get_global(int i)
  */
 void U61_Map::compute_next()
 {
-    //cout<<"Compute next\n";
-    map_time++;
-    if (!(map_time%TIME_CALLBACK_DELAY))
+  //cout<<"Compute next\n";
+  map_time++;
+  update_explosions();
+  if (!(map_time%TIME_CALLBACK_DELAY))
     {
-        time_callback();
-        if (matching)
-        {
-            match_pattern();
-        }
+      time_callback();
     }
-    update_speed();
+
+  if (!exists_explosion())
+    {
+      match_pattern();
+    }
+    
+  update_speed();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -403,24 +406,24 @@ void U61_Map::compute_next()
  */
 void U61_Map::update_speed()
 {
-    check_speed();
-    check_accel();
+  check_speed();
+  check_accel();
 
-    speed_counter+=speeds[speed];
-    if (speed_counter>SPEED_SCALE)
+  speed_counter+=speeds[speed];
+  if (speed_counter>SPEED_SCALE)
     {
-        speed_counter-=SPEED_SCALE;
-        block_move_down(); 
+      speed_counter-=SPEED_SCALE;
+      block_move_down(); 
     }    
-    accel_counter+=accels[accel];
-    if (accel_counter>ACCEL_SCALE)
+  accel_counter+=accels[accel];
+  if (accel_counter>ACCEL_SCALE)
     {
-        accel_counter-=ACCEL_SCALE;
-        speed++;
+      accel_counter-=ACCEL_SCALE;
+      speed++;
     }    
 
-    check_speed();
-    check_accel();
+  check_speed();
+  check_accel();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -429,11 +432,11 @@ void U61_Map::update_speed()
  */
 void U61_Map::compute_up_to(int time)
 {
-    if (active)
+  if (active)
     {
-        while (map_time<time)
+      while (map_time<time)
         {
-            compute_next();
+	  compute_next();
         }
     }
 }
@@ -444,48 +447,48 @@ void U61_Map::compute_up_to(int time)
  */
 void U61_Map::handle_event(U61_Event event)
 {
-    if (active)
+  if (active)
     {
-        if (int(event.time)<map_time)
+      if (int(event.time)<map_time)
         {
-             cout<<"Inconsitency in event dates detected event_time="
-                 <<event.time<<" event_code="<<event.code<<" map_time="
-                 <<map_time<<"\n";
+	  cout<<"Inconsitency in event dates detected event_time="
+	      <<event.time<<" event_code="<<event.code<<" map_time="
+	      <<map_time<<"\n";
         }  
-        else
+      else
         {
-            compute_up_to(event.time);
-            switch (event.code)
+	  compute_up_to(event.time);
+	  switch (event.code)
             {
             case U61_Event::ROTATE_LEFT:
-                block_rotate_left();
-                break;
+	      block_rotate_left();
+	      break;
             case U61_Event::ROTATE_RIGHT:
-                block_rotate_right();
-                break;
+	      block_rotate_right();
+	      break;
             case U61_Event::MOVE_RIGHT:
-                block_move_right();
-                break;
+	      block_move_right();
+	      break;
             case U61_Event::MOVE_LEFT:
-                block_move_left();
-                break;
+	      block_move_left();
+	      break;
             case U61_Event::MOVE_DOWN:
-                block_move_down();
-                break;
+	      block_move_down();
+	      break;
             case U61_Event::DROP:
-                block_drop();
-                break;
+	      block_drop();
+	      break;
             case U61_Event::NEW_BLOCK:
-                new_block(event.par);
-                break;
+	      new_block(event.par);
+	      break;
             case U61_Event::LOOSE:
-                loose();
-                break;
+	      loose();
+	      break;
             }
         }
     }
 
-    //cout<<"Event low level computed code="<<event.code<<"\n";
+  //cout<<"Event low level computed code="<<event.code<<"\n";
 }
 
 /*--------------------------------------------------------------------------*/
@@ -502,8 +505,8 @@ void U61_Map::handle_event(U61_Event event)
  */
 void U61_Map::anticipate(int time)
 {
-    compute_up_to(time);
-    auto_events.clear();
+  compute_up_to(time);
+  auto_events.clear();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -512,17 +515,17 @@ void U61_Map::anticipate(int time)
  */
 void U61_Map::poll_auto_events()
 {
-    U61_Event event;
+  U61_Event event;
 
-    if (active)
+  if (active)
     {
-        if ((!is_block_active()) && (!block_requested) && (!matching))
+      if ((!is_block_active()) && (!block_requested) && (!matching))
         {
-            block_requested=true;
-            event.code=U61_Event::NEW_BLOCK;
-            event.par=U61_Utils::random(U61_Block::MAX_SHAPE);
-            put_auto_event(event);
-            //cout<<"new block event sent\n";
+	  block_requested=true;
+	  event.code=U61_Event::NEW_BLOCK;
+	  event.par=U61_Utils::random(U61_Block::MAX_SHAPE);
+	  put_auto_event(event);
+	  //cout<<"new block event sent\n";
         }
     }
 }
@@ -533,12 +536,12 @@ void U61_Map::poll_auto_events()
  */
 U61_Event U61_Map::get_auto_event()
 {
-    U61_Event event;
+  U61_Event event;
 
-    event=auto_events.front();
-    auto_events.pop_front();
+  event=auto_events.front();
+  auto_events.pop_front();
 
-    return event;
+  return event;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -547,7 +550,7 @@ U61_Event U61_Map::get_auto_event()
  */
 bool U61_Map::exists_auto_event()
 {
-    return !auto_events.empty();
+  return !auto_events.empty();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -556,8 +559,8 @@ bool U61_Map::exists_auto_event()
  */
 void U61_Map::put_auto_event(U61_Event event)
 {
-    event.time=U61_Time::for_event();
-    auto_events.push_back(event);
+  event.time=U61_Time::for_event();
+  auto_events.push_back(event);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -566,42 +569,42 @@ void U61_Map::put_auto_event(U61_Event event)
  */
 void U61_Map::draw(int x,int y, int size, bool prev)
 {
-    int i,j;
-    int x_square_offset;
-    int y_square_offset;
+  int i,j;
+  int x_square_offset;
+  int y_square_offset;
 
-    if (active)
+  if (active)
     {
-        x_square_offset=
-            (U61_Global::data.map_w[size]
-            -WIDTH*U61_Global::data.square_w[size])/2;
-        y_square_offset=
-            (U61_Global::data.map_h[size]
-            -HEIGHT*U61_Global::data.square_h[size])/2;
+      x_square_offset=
+	(U61_Global::data.map_w[size]
+	 -WIDTH*U61_Global::data.square_w[size])/2;
+      y_square_offset=
+	(U61_Global::data.map_h[size]
+	 -HEIGHT*U61_Global::data.square_h[size])/2;
         
-        x_square_offset+=x;
-        y_square_offset+=y;
+      x_square_offset+=x;
+      y_square_offset+=y;
 
-        U61_Global::data.map[background][size]->put_screen(x,y);
+      U61_Global::data.map[background][size]->put_screen(x,y);
 
-        for (j=0;j<HEIGHT;++j)
+      for (j=0;j<HEIGHT;++j)
         {
-            for (i=0;i<WIDTH;++i)
+	  for (i=0;i<WIDTH;++i)
             {
-                squares[i][j].draw(x_square_offset
-                                   +i*U61_Global::data.square_w[size],
-                                   y_square_offset
-                                   +j*U61_Global::data.square_h[size],
-                                   size);
+	      squares[i][j].draw(x_square_offset
+				 +i*U61_Global::data.square_w[size],
+				 y_square_offset
+				 +j*U61_Global::data.square_h[size],
+				 size);
             }
         }
-        if (prevision_state && prev)
+      if (prevision_state && prev)
         {
-            draw_prevision(x_square_offset,y_square_offset,size);
+	  draw_prevision(x_square_offset,y_square_offset,size);
         }
-        block.draw(x_square_offset,y_square_offset,size);
+      block.draw(x_square_offset,y_square_offset,size);
     }
-//    cout<<"draw square\n";
+  //    cout<<"draw square\n";
 }
 
 /*--------------------------------------------------------------------------*/
@@ -610,7 +613,7 @@ void U61_Map::draw(int x,int y, int size, bool prev)
  */
 void U61_Map::mute()
 {
-    silent=true;
+  silent=true;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -619,7 +622,7 @@ void U61_Map::mute()
  */
 void U61_Map::set_prevision_state(bool state)
 {
-    prevision_state=state; 
+  prevision_state=state; 
 }
 
 /*--------------------------------------------------------------------------*/
@@ -628,7 +631,7 @@ void U61_Map::set_prevision_state(bool state)
  */
 bool U61_Map::get_prevision_state()
 {
-    return prevision_state; 
+  return prevision_state; 
 }
 
 /*--------------------------------------------------------------------------*/
@@ -637,7 +640,7 @@ bool U61_Map::get_prevision_state()
  */
 void U61_Map::set_preview_state(bool state)
 {
-    preview_state=state; 
+  preview_state=state; 
 }
 
 /*--------------------------------------------------------------------------*/
@@ -646,7 +649,7 @@ void U61_Map::set_preview_state(bool state)
  */
 bool U61_Map::get_preview_state()
 {
-    return preview_state; 
+  return preview_state; 
 }
 
 /*--------------------------------------------------------------------------*/
@@ -655,8 +658,8 @@ bool U61_Map::get_preview_state()
  */
 void U61_Map::set_speed(int s)
 {
-    speed=s; 
-    check_speed();
+  speed=s; 
+  check_speed();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -665,7 +668,7 @@ void U61_Map::set_speed(int s)
  */
 int U61_Map::get_speed()
 {
-    return speed; 
+  return speed; 
 }
 
 /*--------------------------------------------------------------------------*/
@@ -674,13 +677,13 @@ int U61_Map::get_speed()
  */
 void U61_Map::check_speed()
 {
-    if (speed>MAX_SYSTEM_SPEED)
+  if (speed>MAX_SYSTEM_SPEED)
     {
-        speed=MAX_SYSTEM_SPEED;
+      speed=MAX_SYSTEM_SPEED;
     }
-    if (speed<0)
+  if (speed<0)
     {
-        speed=0;
+      speed=0;
     }
 }
 
@@ -690,8 +693,8 @@ void U61_Map::check_speed()
  */
 void U61_Map::set_accel(int a)
 {
-    accel=a; 
-    check_accel();
+  accel=a; 
+  check_accel();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -700,7 +703,7 @@ void U61_Map::set_accel(int a)
  */
 int U61_Map::get_accel()
 {
-    return accel; 
+  return accel; 
 }
 
 /*--------------------------------------------------------------------------*/
@@ -709,13 +712,13 @@ int U61_Map::get_accel()
  */
 void U61_Map::check_accel()
 {
-    if (accel>MAX_SYSTEM_ACCEL)
+  if (accel>MAX_SYSTEM_ACCEL)
     {
-        accel=MAX_SYSTEM_ACCEL;
+      accel=MAX_SYSTEM_ACCEL;
     }
-    if (accel<0)
+  if (accel<0)
     {
-        accel=0;
+      accel=0;
     }
 }
 
@@ -725,7 +728,56 @@ void U61_Map::check_accel()
  */
 U61_Block U61_Map::get_next_block()
 {
-    return next_block; 
+  return next_block; 
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * puts the square in an exploding state
+ */
+void U61_Map::blow_up_square(int x,int y)
+{
+  if (x>=0 && y>=0 && x<WIDTH && y<HEIGHT)
+    {
+      squares[x][y].begin_explosion();
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Returns true if the square is exploding
+ */
+bool U61_Map::is_square_exploding(int x,int y)
+{
+  bool result=false;
+
+  if (x>=0 && y>=0 && x<WIDTH && y<HEIGHT)
+    {
+      result= squares[x][y].is_exploding();
+    }
+    
+  return result;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Returns true if there's at least one square exploding
+ */
+bool U61_Map::exists_explosion()
+{
+  bool result=false;
+  int x,y;
+
+  for (y=0;y<HEIGHT;++y)
+    for (x=0;x<WIDTH;++x)
+      {
+	if (squares[x][y].is_exploding())
+	  {
+	    result=true;
+	  } 
+      }
+
+  return result;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -735,21 +787,21 @@ U61_Block U61_Map::get_next_block()
  */
 void U61_Map::draw_prevision(int x,int y,int size)
 {
-    U61_Block test;
-    U61_Block prev;
+  U61_Block test;
+  U61_Block prev;
 
-    if (block.get_nb_items()>0)
+  if (block.get_nb_items()>0)
     {
-        test=block;
+      test=block;
     
-        while (is_block_ok(&test))
+      while (is_block_ok(&test))
         {
-            prev=test;
-            test.move_down();
+	  prev=test;
+	  test.move_down();
         }
 
-        U61_Script::block_land(this,&prev);
-        prev.draw_prevision(x,y,size); 
+      U61_Script::block_land(this,&prev);
+      prev.draw_prevision(x,y,size); 
     }
 }
 
@@ -760,32 +812,32 @@ void U61_Map::draw_prevision(int x,int y,int size)
  */
 void U61_Map::block_rotate_left()
 {
-    //cout<<"rotate left\n";
-    U61_Block test;
+  //cout<<"rotate left\n";
+  U61_Block test;
 
-    test=block;
-    test.rotate_left();
-    if (is_block_ok(&test))
+  test=block;
+  test.rotate_left();
+  if (is_block_ok(&test))
     {
-        block=test;
+      block=test;
     }
-    else
+  else
     {
-        test=block;
-        test.move_left();
-        test.rotate_left(); 
-        if (is_block_ok(&test))
+      test=block;
+      test.move_left();
+      test.rotate_left(); 
+      if (is_block_ok(&test))
         {
-            block=test;
+	  block=test;
         }
-        else
+      else
         {
-            test=block;
-            test.move_right();
-            test.rotate_left(); 
-            if (is_block_ok(&test))
+	  test=block;
+	  test.move_right();
+	  test.rotate_left(); 
+	  if (is_block_ok(&test))
             {
-                block=test;
+	      block=test;
             }
         }
     }
@@ -798,32 +850,32 @@ void U61_Map::block_rotate_left()
  */
 void U61_Map::block_rotate_right()
 {
-    //cout<<"rotate right\n";
-    U61_Block test;
+  //cout<<"rotate right\n";
+  U61_Block test;
 
-    test=block;
-    test.rotate_right();
-    if (is_block_ok(&test))
+  test=block;
+  test.rotate_right();
+  if (is_block_ok(&test))
     {
-        block=test;
+      block=test;
     }
-    else
+  else
     {
-        test=block;
-        test.move_right();
-        test.rotate_right(); 
-        if (is_block_ok(&test))
+      test=block;
+      test.move_right();
+      test.rotate_right(); 
+      if (is_block_ok(&test))
         {
-            block=test;
+	  block=test;
         }
-        else
+      else
         {
-            test=block;
-            test.move_left();
-            test.rotate_right(); 
-            if (is_block_ok(&test))
+	  test=block;
+	  test.move_left();
+	  test.rotate_right(); 
+	  if (is_block_ok(&test))
             {
-                block=test;
+	      block=test;
             }
         }
     }
@@ -836,14 +888,14 @@ void U61_Map::block_rotate_right()
  */
 void U61_Map::block_move_left()
 {
-    //cout<<"move left\n";
-    U61_Block test;
+  //cout<<"move left\n";
+  U61_Block test;
 
-    test=block;
-    test.move_left();
-    if (is_block_ok(&test))
+  test=block;
+  test.move_left();
+  if (is_block_ok(&test))
     {
-        block=test;
+      block=test;
     }
 }
 
@@ -854,14 +906,14 @@ void U61_Map::block_move_left()
  */
 void U61_Map::block_move_right()
 {
-    //cout<<"move right\n";
-    U61_Block test;
+  //cout<<"move right\n";
+  U61_Block test;
 
-    test=block;
-    test.move_right();
-    if (is_block_ok(&test))
+  test=block;
+  test.move_right();
+  if (is_block_ok(&test))
     {
-        block=test;
+      block=test;
     }
 }
 
@@ -872,18 +924,18 @@ void U61_Map::block_move_right()
  */
 void U61_Map::block_move_down()
 {
-    //cout<<"move down\n";
-    U61_Block test;
+  //cout<<"move down\n";
+  U61_Block test;
 
-    test=block;
-    test.move_down();
-    if (is_block_ok(&test))
+  test=block;
+  test.move_down();
+  if (is_block_ok(&test))
     {
-        block=test;
+      block=test;
     }
-    else
+  else
     {
-        stabilize_block();
+      stabilize_block();
     }
 }
 
@@ -893,19 +945,19 @@ void U61_Map::block_move_down()
  */
 void U61_Map::block_drop()
 {
-    //cout<<"drop\n";
-    U61_Block test;
+  //cout<<"drop\n";
+  U61_Block test;
 
-    test=block;
-    if (block.get_nb_items()>0)
+  test=block;
+  if (block.get_nb_items()>0)
     {
-        while (is_block_ok(&test))
+      while (is_block_ok(&test))
         {
-            block=test;
-            test.move_down();
+	  block=test;
+	  test.move_down();
         }
     
-        stabilize_block();
+      stabilize_block();
     }
 }
 
@@ -916,7 +968,7 @@ void U61_Map::block_drop()
  */
 bool U61_Map::is_block_active()
 {
-    return block.get_nb_items()>0;
+  return block.get_nb_items()>0;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -928,39 +980,39 @@ bool U61_Map::is_block_active()
  */
 bool U61_Map::is_block_ok(U61_Block *test)
 {
-    int i,n,x,y;
-    bool ok=true;
+  int i,n,x,y;
+  bool ok=true;
 
-    n=test->get_nb_items();
-    for (i=0;i<n && ok;++i)
+  n=test->get_nb_items();
+  for (i=0;i<n && ok;++i)
     {
-        x=test->get_x()+test->get_item_x(i);
-        y=test->get_y()+test->get_item_y(i);
-        /*
-         * the square must be in the map, or over the map,
-         * if the block is brand new and didn't show himself yet
-         */
-        if (x>=0 && x<WIDTH && y<HEIGHT)
+      x=test->get_x()+test->get_item_x(i);
+      y=test->get_y()+test->get_item_y(i);
+      /*
+       * the square must be in the map, or over the map,
+       * if the block is brand new and didn't show himself yet
+       */
+      if (x>=0 && x<WIDTH && y<HEIGHT)
         {
-            /*
-             * if y>=0, there could potentially be a stable square
-             * at this location, so we check that
-             */
-            if (y>=0)
+	  /*
+	   * if y>=0, there could potentially be a stable square
+	   * at this location, so we check that
+	   */
+	  if (y>=0)
             {
-                if (squares[x][y].is_enabled()) 
+	      if (squares[x][y].is_enabled()) 
                 {
-                    ok=false;
+		  ok=false;
                 }
             }
         }
-        else
+      else
         {
-            ok=false;
+	  ok=false;
         }
     }
 
-    return ok;
+  return ok;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -970,16 +1022,16 @@ bool U61_Map::is_block_ok(U61_Block *test)
  */
 void U61_Map::new_block(int shape)
 {
-    block=next_block;
-    block.set_x(WIDTH/2);
-    block_requested=false;
+  block=next_block;
+  block.set_x(WIDTH/2);
+  block_requested=false;
 
-    next_block.shape(shape);
+  next_block.shape(shape);
 
-    next_block.corner();
-    block.center();
+  next_block.corner();
+  block.center();
 
-    //cout<<"new block given\n";
+  //cout<<"new block given\n";
 }
 
 /*--------------------------------------------------------------------------*/
@@ -989,37 +1041,37 @@ void U61_Map::new_block(int shape)
  */
 void U61_Map::stabilize_block()
 {
-    U61_Event evt;
-    int x,y,i,n;
-    bool outside=false;
+  U61_Event evt;
+  int x,y,i,n;
+  bool outside=false;
 
-    U61_Script::block_land(this,&block);
-    n=block.get_nb_items();
-    for (i=0;i<n;++i)
+  U61_Script::block_land(this,&block);
+  n=block.get_nb_items();
+  for (i=0;i<n;++i)
     {
-        x=block.get_x()+block.get_item_x(i);
-        y=block.get_y()+block.get_item_y(i);
-        if (x>=0 && y>=0 && x<WIDTH && y<HEIGHT)
+      x=block.get_x()+block.get_item_x(i);
+      y=block.get_y()+block.get_item_y(i);
+      if (x>=0 && y>=0 && x<WIDTH && y<HEIGHT)
         {
-            squares[x][y]=block.get_item(i)->square;
+	  squares[x][y]=block.get_item(i)->square;
         }
-        else
+      else
         {
-            outside=true;
+	  outside=true;
         }
     }
-    if (outside)
+  if (outside)
     {
-        evt.code=U61_Event::LOOSE;
-        put_auto_event(evt);
+      evt.code=U61_Event::LOOSE;
+      put_auto_event(evt);
     }
-    else
+  else
     {
-        match_count=0;
-        matching=true;
+      match_count=0;
+      matching=true;
     }
 
-    block.reset();
+  block.reset();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -1028,8 +1080,8 @@ void U61_Map::stabilize_block()
  */
 void U61_Map::loose()
 {
-    //cout<<"The game is lost\n";
-    begin();
+  //cout<<"The game is lost\n";
+  begin();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -1042,23 +1094,23 @@ void U61_Map::loose()
  */
 void U61_Map::match_pattern()
 {
-    if (matching)
+  if (matching)
     {
-        if ((U61_Script::map_match_pattern(this)))
+      if ((U61_Script::map_match_pattern(this)))
         {
-            if (!silent)
+	  if (!silent)
             {
-                U61_Sound::play_block_pattern();
+	      U61_Sound::play_block_pattern();
             }
-            match_count++;
+	  match_count++;
         }
-        else
+      else
         {
-            if (match_count==0 && !silent)
+	  if (match_count==0 && !silent)
             {
-                U61_Sound::play_block_touch();
+	      U61_Sound::play_block_touch();
             }
-            matching=false;
+	  matching=false;
         }
     }
 }
@@ -1072,5 +1124,25 @@ void U61_Map::match_pattern()
  */
 void U61_Map::time_callback()
 {
-    U61_Script::map_time_callback(this,&block);
+  U61_Script::map_time_callback(this,&block);
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Calls the update_explosion function for each square,
+ * ie each explosion counter will be increased by 1
+ */
+void U61_Map::update_explosions()
+{
+  int x,y;
+
+  for (y=0;y<HEIGHT;++y)
+    for (x=0;x<WIDTH;++x)
+      { 
+	squares[x][y].update_explosion();
+	if (squares[x][y].is_explosion_ended())
+	  {
+	    U61_Script::map_square_blown_up(this,x,y);
+	  }
+      }
 }
