@@ -55,7 +55,7 @@
  */
 char *U61_Menu::bottom_message[BOTTOM_MESSAGE_NB]=
 {
-    "U61, another block-game by U-Foot",
+    "U61, another block-based game by U-Foot",
     "Copyright (C) 2000 Christian Mauduit",
     "Home page : http://www.ufoot.org/u61",
     "Contact author : ufoot@ufoot.org",
