@@ -39,14 +39,24 @@
  includes
  ---------------------------------------------------------------------------*/
 
+#include <sys/types.h>
+#include <dirent.h>
 #include <stdlib.h>
 
 #include "platform.h"
+#include "const.h"
 
 /*---------------------------------------------------------------------------
  variants
  ---------------------------------------------------------------------------*/
 
+/*--------------------------------------------------------------------------*/
+/*
+ * global variables for directory scan functions
+ */
+static DIR *scan_dir=NULL;
+static char *scan_ext=NULL;
+
 /*---------------------------------------------------------------------------
  functions
  ---------------------------------------------------------------------------*/
@@ -57,7 +67,7 @@
  */
 char *U61_Platform::get_config_file()
 {
-    static char buffer[1000]; 
+    static char buffer[U61_STRING_SIZE]; 
     int len;
 
     strcpy (buffer,getenv("HOME"));
@@ -81,7 +91,7 @@ char *U61_Platform::get_config_file()
  */
 char *U61_Platform::get_data_path()
 {
-    static char buffer[1000]; 
+    static char buffer[U61_STRING_SIZE]; 
     int len;
 
 
@@ -98,3 +108,75 @@ char *U61_Platform::get_data_path()
 
     return buffer;
 }
+
+/*--------------------------------------------------------------------------*/
+/*
+ * opens a directory for file scanning
+ */
+bool U61_Platform::open_dir(char *dir, char *ext)
+{
+    bool ok=false;
+
+    scan_ext=ext;
+    scan_dir=opendir(dir);
+    if (scan_dir!=NULL)
+    {
+        ok=true;
+    }
+
+    return ok;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * retrieves the next file in the directory
+ */
+char *U61_Platform::next_file()
+{
+    char *name=NULL;
+    struct dirent *d;
+    bool end=false;
+    int len1,len2;
+
+    do 
+    {
+        d=readdir(scan_dir);
+        if (d==NULL)
+        {
+            name=NULL;
+            end=true;
+        }
+        else
+        {
+            name=d->d_name;
+            len1=strlen(name); 
+            len2=strlen(scan_ext); 
+            if (len2<=len1)
+            {
+                if (strcasecmp(name+len1-len2,scan_ext)==0)
+                {
+                    end=true;
+                }
+            }
+        }
+    }
+    while (!end);
+
+    return name;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * closes the directory
+ */
+bool U61_Platform::close_dir()
+{
+    bool ok=false;
+
+    if (closedir(scan_dir)==0)
+    {
+        ok=true;
+    }
+ 
+    return ok;
+}
