@@ -136,6 +136,33 @@ char *U61_Player::get_name()
     return name;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the score of a player
+ */
+int U61_Player::get_score()
+{
+    return last.get_score();
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the best score of a player
+ */
+int U61_Player::get_best_score()
+{
+    return sure.get_best_score();
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the next block of a player
+ */
+U61_Block U61_Player::get_next_block()
+{
+    return last.get_next_block();
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * sets the player as a local player
@@ -149,7 +176,7 @@ void U61_Player::init_local(U61_Input *input,int time,
     reset();
     sure.reset(U61_Global::config.initial_speed,
                U61_Global::config.acceleration);
-    last=sure;
+    copy_sure_to_last();
     name=conf->name;
     prevision=&(conf->prevision);
     //cout<<"init local with "<<name<<"\n";
@@ -204,9 +231,7 @@ void U61_Player::pump_events()
 
     if (changed)
     {
-        //sure.copy_to(&last);
-        //cout<<"sure copied to last\n";
-        last=sure;
+        copy_sure_to_last();
     }
 }
 
@@ -244,7 +269,7 @@ void U61_Player::handle_event(U61_Event evt)
 void U61_Player::start(int time)
 {
     sure.set_active(time);
-    last=sure;
+    copy_sure_to_last();
     //cout<<"Player "<<id<<" started\n";
 }
 
@@ -255,7 +280,7 @@ void U61_Player::start(int time)
 void U61_Player::stop()
 {
     sure.set_inactive();
-    last=sure;
+    copy_sure_to_last();
     //cout<<"Player "<<id<<" stopped\n";
 }
 
@@ -269,3 +294,13 @@ void U61_Player::draw(int x,int y,int size)
     //last.draw(10,10);
     last.draw(x,y,size,*prevision);
 }
+
+/*--------------------------------------------------------------------------*/
+/*
+ * copies the sure map to the last map
+ */
+void U61_Player::copy_sure_to_last()
+{
+    last=sure;
+    last.mute();
+}
