@@ -82,6 +82,9 @@ public:
     int get_id();
 
     char *get_name();
+    int get_score();
+    int get_best_score();
+    U61_Block get_next_block();
 
     void init_local(U61_Input *input,int time,
                     U61_PlayerConfig *conf,
@@ -109,6 +112,8 @@ protected:
     void handle_event(U61_Event evt);
     void start(int time);
     void stop();
+
+    void copy_sure_to_last();
 };
 
 #endif
