@@ -91,11 +91,11 @@ static bool map_write=false;
  */
 bool U61_Script::do_string(char *str)
 {
-    bool bSuccess;
+  bool bSuccess;
 
-    bSuccess=false;
+  bSuccess=false;
 
-    return bSuccess;
+  return bSuccess;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -104,25 +104,25 @@ bool U61_Script::do_string(char *str)
  */
 bool U61_Script::do_file(char *name)
 {
-    bool bSuccess;
-    int iResult;
+  bool bSuccess;
+  int iResult;
 
-    bSuccess=false;
+  bSuccess=false;
 
-    //lua_open();
-    //cout<<"Loading script from \""<<name<<"\".\n";
-    iResult=CL_Lua::dofile(name);
-    switch (iResult)
+  //lua_open();
+  //cout<<"Loading script from \""<<name<<"\".\n";
+  iResult=CL_Lua::dofile(name);
+  switch (iResult)
     {
     case 0:
-        bSuccess=true;
-        break;
+      bSuccess=true;
+      break;
     default:
-    //    cout<<"Lua error "<<iResult<<".\n";
-        break;
+      //    cout<<"Lua error "<<iResult<<".\n";
+      break;
     }
 
-    return bSuccess;
+  return bSuccess;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -131,16 +131,16 @@ bool U61_Script::do_file(char *name)
  */
 char *U61_Script::get_global_str(char *name,char *def)
 {
-    CL_LuaObject obj;
-    char *result=def;
+  CL_LuaObject obj;
+  char *result=def;
 
-    obj=CL_Lua::getglobal(name);
-    if (obj.isString())
+  obj=CL_Lua::getglobal(name);
+  if (obj.isString())
     {
-        result=obj;
+      result=obj;
     }    
 
-    return result;
+  return result;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -149,16 +149,16 @@ char *U61_Script::get_global_str(char *name,char *def)
  */
 int U61_Script::get_global_int(char *name,int def)
 {
-    CL_LuaObject obj;
-    float result=def;
+  CL_LuaObject obj;
+  float result=def;
 
-    obj=CL_Lua::getglobal(name);
-    if (obj.isNumber())
+  obj=CL_Lua::getglobal(name);
+  if (obj.isNumber())
     {
-        result=obj;
+      result=obj;
     }    
 
-    return (int) result;
+  return (int) result;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -167,12 +167,12 @@ int U61_Script::get_global_int(char *name,int def)
  */
 bool U61_Script::init()
 {
-    bool bSuccess=true;
+  bool bSuccess=true;
 
-    CL_Lua::mathlibopen();
-    record_all();
+  CL_Lua::mathlibopen();
+  record_all();
 
-    return bSuccess;
+  return bSuccess;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -183,12 +183,12 @@ bool U61_Script::init()
  */
 void U61_Script::secure_pointers()
 {
-    current_block=NULL;
-    current_map=NULL;
-    block_read=false;
-    block_write=false;
-    map_read=false;
-    map_write=false;
+  current_block=NULL;
+  current_map=NULL;
+  block_read=false;
+  block_write=false;
+  map_read=false;
+  map_write=false;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -198,22 +198,22 @@ void U61_Script::secure_pointers()
  */
 void U61_Script::block_shape(U61_Block *b, int type)
 {
-    CL_LuaObject func;
-    char command[U61_STRING_SIZE];
-    char arguments[U61_STRING_SIZE];
+  CL_LuaObject func;
+  char command[U61_STRING_SIZE];
+  char arguments[U61_STRING_SIZE];
 
-    secure_pointers();
-    current_block=b;
-    block_read=true;
-    block_write=true;
+  secure_pointers();
+  current_block=b;
+  block_read=true;
+  block_write=true;
 
-    //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
-    //lua_callfunction(func);
+  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //lua_callfunction(func);
 
-    sprintf(arguments,"(%d)",type);
-    strcpy(command,LUA_BLOCK_SHAPE);
-    strcat(command,arguments);
-    CL_Lua::dostring(command);
+  sprintf(arguments,"(%d)",type);
+  strcpy(command,LUA_BLOCK_SHAPE);
+  strcat(command,arguments);
+  CL_Lua::dostring(command);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -224,22 +224,22 @@ void U61_Script::block_shape(U61_Block *b, int type)
  */
 void U61_Script::block_rotate_right(U61_Block *b)
 {
-    CL_LuaObject func;
-    char command[U61_STRING_SIZE];
-    char arguments[U61_STRING_SIZE];
+  CL_LuaObject func;
+  char command[U61_STRING_SIZE];
+  char arguments[U61_STRING_SIZE];
 
-    secure_pointers();
-    current_block=b;
-    block_read=true;
-    block_write=true;
+  secure_pointers();
+  current_block=b;
+  block_read=true;
+  block_write=true;
 
-    //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
-    //lua_callfunction(func);
+  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //lua_callfunction(func);
 
-    sprintf(arguments,"()");
-    strcpy(command,LUA_BLOCK_ROTATE_RIGHT);
-    strcat(command,arguments);
-    CL_Lua::dostring(command);
+  sprintf(arguments,"()");
+  strcpy(command,LUA_BLOCK_ROTATE_RIGHT);
+  strcat(command,arguments);
+  CL_Lua::dostring(command);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -250,22 +250,22 @@ void U61_Script::block_rotate_right(U61_Block *b)
  */
 void U61_Script::block_rotate_left(U61_Block *b)
 {
-    CL_LuaObject func;
-    char command[U61_STRING_SIZE];
-    char arguments[U61_STRING_SIZE];
+  CL_LuaObject func;
+  char command[U61_STRING_SIZE];
+  char arguments[U61_STRING_SIZE];
 
-    secure_pointers();
-    current_block=b;
-    block_read=true;
-    block_write=true;
+  secure_pointers();
+  current_block=b;
+  block_read=true;
+  block_write=true;
 
-    //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
-    //lua_callfunction(func);
+  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //lua_callfunction(func);
 
-    sprintf(arguments,"()");
-    strcpy(command,LUA_BLOCK_ROTATE_LEFT);
-    strcat(command,arguments);
-    CL_Lua::dostring(command);
+  sprintf(arguments,"()");
+  strcpy(command,LUA_BLOCK_ROTATE_LEFT);
+  strcat(command,arguments);
+  CL_Lua::dostring(command);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -276,22 +276,22 @@ void U61_Script::block_rotate_left(U61_Block *b)
  */
 void U61_Script::block_move_right(U61_Block *b)
 {
-    CL_LuaObject func;
-    char command[U61_STRING_SIZE];
-    char arguments[U61_STRING_SIZE];
+  CL_LuaObject func;
+  char command[U61_STRING_SIZE];
+  char arguments[U61_STRING_SIZE];
 
-    secure_pointers();
-    current_block=b;
-    block_read=true;
-    block_write=true;
+  secure_pointers();
+  current_block=b;
+  block_read=true;
+  block_write=true;
 
-    //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
-    //lua_callfunction(func);
+  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //lua_callfunction(func);
 
-    sprintf(arguments,"()");
-    strcpy(command,LUA_BLOCK_MOVE_RIGHT);
-    strcat(command,arguments);
-    CL_Lua::dostring(command);
+  sprintf(arguments,"()");
+  strcpy(command,LUA_BLOCK_MOVE_RIGHT);
+  strcat(command,arguments);
+  CL_Lua::dostring(command);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -302,22 +302,22 @@ void U61_Script::block_move_right(U61_Block *b)
  */
 void U61_Script::block_move_left(U61_Block *b)
 {
-    CL_LuaObject func;
-    char command[U61_STRING_SIZE];
-    char arguments[U61_STRING_SIZE];
+  CL_LuaObject func;
+  char command[U61_STRING_SIZE];
+  char arguments[U61_STRING_SIZE];
 
-    secure_pointers();
-    current_block=b;
-    block_read=true;
-    block_write=true;
+  secure_pointers();
+  current_block=b;
+  block_read=true;
+  block_write=true;
 
-    //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
-    //lua_callfunction(func);
+  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //lua_callfunction(func);
 
-    sprintf(arguments,"()");
-    strcpy(command,LUA_BLOCK_MOVE_LEFT);
-    strcat(command,arguments);
-    CL_Lua::dostring(command);
+  sprintf(arguments,"()");
+  strcpy(command,LUA_BLOCK_MOVE_LEFT);
+  strcat(command,arguments);
+  CL_Lua::dostring(command);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -328,22 +328,22 @@ void U61_Script::block_move_left(U61_Block *b)
  */
 void U61_Script::block_move_down(U61_Block *b)
 {
-    CL_LuaObject func;
-    char command[U61_STRING_SIZE];
-    char arguments[U61_STRING_SIZE];
+  CL_LuaObject func;
+  char command[U61_STRING_SIZE];
+  char arguments[U61_STRING_SIZE];
 
-    secure_pointers();
-    current_block=b;
-    block_read=true;
-    block_write=true;
+  secure_pointers();
+  current_block=b;
+  block_read=true;
+  block_write=true;
 
-    //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
-    //lua_callfunction(func);
+  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //lua_callfunction(func);
 
-    sprintf(arguments,"()");
-    strcpy(command,LUA_BLOCK_MOVE_DOWN);
-    strcat(command,arguments);
-    CL_Lua::dostring(command);
+  sprintf(arguments,"()");
+  strcpy(command,LUA_BLOCK_MOVE_DOWN);
+  strcat(command,arguments);
+  CL_Lua::dostring(command);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -354,24 +354,24 @@ void U61_Script::block_move_down(U61_Block *b)
  */
 void U61_Script::block_land(U61_Map *m,U61_Block *b)
 {
-    CL_LuaObject func;
-    char command[U61_STRING_SIZE];
-    char arguments[U61_STRING_SIZE];
+  CL_LuaObject func;
+  char command[U61_STRING_SIZE];
+  char arguments[U61_STRING_SIZE];
 
-    secure_pointers();
-    current_block=b;
-    block_read=true;
-    block_write=true;
-    current_map=m;
-    map_read=true;
+  secure_pointers();
+  current_block=b;
+  block_read=true;
+  block_write=true;
+  current_map=m;
+  map_read=true;
 
-    //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
-    //lua_callfunction(func);
+  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //lua_callfunction(func);
 
-    sprintf(arguments,"()");
-    strcpy(command,LUA_BLOCK_LAND);
-    strcat(command,arguments);
-    CL_Lua::dostring(command);
+  sprintf(arguments,"()");
+  strcpy(command,LUA_BLOCK_LAND);
+  strcat(command,arguments);
+  CL_Lua::dostring(command);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -382,48 +382,48 @@ void U61_Script::block_land(U61_Map *m,U61_Block *b)
  */
 bool U61_Script::map_match_pattern(U61_Map *m)
 {
-    CL_LuaObject func;
-    CL_LuaObject obj;
-    CL_LuaObject arg1;
-    char command[U61_STRING_SIZE];
-    char arguments[U61_STRING_SIZE];
-    float result=0.;
+  CL_LuaObject func;
+  CL_LuaObject obj;
+  CL_LuaObject arg1;
+  char command[U61_STRING_SIZE];
+  char arguments[U61_STRING_SIZE];
+  float result=0.;
 
-    secure_pointers();
-    current_map=m;
-    map_read=true;
-    map_write=true;
+  secure_pointers();
+  current_map=m;
+  map_read=true;
+  map_write=true;
 
-    //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
-    //lua_callfunction(func);
+  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //lua_callfunction(func);
 
-    sprintf(arguments,"(%d)",m->get_match_count());
-    strcpy(command,LUA_MAP_MATCH_PATTERN);
-    strcat(command,arguments);
-    //CL_Lua::dostring(command);
+  sprintf(arguments,"(%d)",m->get_match_count());
+  strcpy(command,LUA_MAP_MATCH_PATTERN);
+  strcat(command,arguments);
+  //CL_Lua::dostring(command);
 
-    //arg1=m->get_match_count();
-    //func=CL_Lua::getglobal(LUA_MAP_MATCH_PATTERN);
-    //CL_Lua::pushobject(arg1);
-    //CL_Lua::callfunction(func);
+  //arg1=m->get_match_count();
+  //func=CL_Lua::getglobal(LUA_MAP_MATCH_PATTERN);
+  //CL_Lua::pushobject(arg1);
+  //CL_Lua::callfunction(func);
 
-    //obj=CL_Lua::getresult(0);
-    lua_pushnumber(m->get_match_count());
-    lua_callfunction(lua_getglobal(LUA_MAP_MATCH_PATTERN));
-    result=lua_getnumber(lua_getresult(1));
+  //obj=CL_Lua::getresult(0);
+  lua_pushnumber(m->get_match_count());
+  lua_callfunction(lua_getglobal(LUA_MAP_MATCH_PATTERN));
+  result=lua_getnumber(lua_getresult(1));
 
-//    if (obj.isNumber())
-//    {
-//        cout<<"is a number";
-//        result=obj;
-//    }    
-//    else
-//    {
-//        cout<<"not a number";
-//    }
-//    cout<<"c:"<<result<<"\n";
+  //    if (obj.isNumber())
+  //    {
+  //        cout<<"is a number";
+  //        result=obj;
+  //    }    
+  //    else
+  //    {
+  //        cout<<"not a number";
+  //    }
+  //    cout<<"c:"<<result<<"\n";
 
-    return (result>0.);
+  return (result>0.);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -436,28 +436,58 @@ bool U61_Script::map_match_pattern(U61_Map *m)
  */
 void U61_Script::map_time_callback(U61_Map *m,U61_Block *b)
 {
-    CL_LuaObject func;
-    char command[U61_STRING_SIZE];
-    char arguments[U61_STRING_SIZE];
+  CL_LuaObject func;
+  char command[U61_STRING_SIZE];
+  char arguments[U61_STRING_SIZE];
 
-    secure_pointers();
-    current_map=m;
-    current_block=b;
-    map_read=true;
-    map_write=true;
-    block_read=true;
-    block_write=true;
+  secure_pointers();
+  current_map=m;
+  current_block=b;
+  map_read=true;
+  map_write=true;
+  block_read=true;
+  block_write=true;
 
-    //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
-    //lua_callfunction(func);
+  //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+  //lua_callfunction(func);
 
-    sprintf(arguments,"()");
-    strcpy(command,LUA_MAP_TIME_CALLBACK);
-    strcat(command,arguments);
-    CL_Lua::dostring(command);
+  sprintf(arguments,"()");
+  strcpy(command,LUA_MAP_TIME_CALLBACK);
+  strcat(command,arguments);
+  CL_Lua::dostring(command);
 
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * calls the user defined function that handles the end of an explosion
+ * Usually it makes the square disappear and shifts the upper squares
+ * of one row down, but it can do other things, for instance blow up
+ * some other blocks!
+ */
+void U61_Script::map_square_blown_up(U61_Map *m,int x,int y)
+{
+  CL_LuaObject func;
+  CL_LuaObject obj;
+  CL_LuaObject arg1;
+  char command[U61_STRING_SIZE];
+  char arguments[U61_STRING_SIZE];
+
+  secure_pointers();
+  current_map=m;
+  map_read=true;
+  map_write=true;
+
+  //  lua_pushnumber(x);
+  //  lua_pushnumber(y);
+  //  lua_callfunction(lua_getglobal(LUA_MAP_SQUARE_BLOWN_UP));
+
+  sprintf(arguments,"(%d,%d)",x,y);
+  strcpy(command,LUA_MAP_SQUARE_BLOWN_UP);
+  strcat(command,arguments);
+  CL_Lua::dostring(command);
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * this function is accessible from lua script 
@@ -465,9 +495,9 @@ void U61_Script::map_time_callback(U61_Map *m,U61_Block *b)
  */
 static void block_reset()
 {
-    if (current_block!=NULL && block_write)
+  if (current_block!=NULL && block_write)
     {
-        current_block->reset();
+      current_block->reset();
     }
 }
 
@@ -478,9 +508,9 @@ static void block_reset()
  */
 static void block_center()
 {
-    if (current_block!=NULL && block_write)
+  if (current_block!=NULL && block_write)
     {
-        current_block->center();
+      current_block->center();
     }
 }
 
@@ -491,13 +521,13 @@ static void block_center()
  */
 static void block_get_x()
 {
-    CL_LuaValue *x;
+  CL_LuaValue *x;
 
-    if (current_block!=NULL && block_read)
+  if (current_block!=NULL && block_read)
     {
-        x=new CL_LuaValue(current_block->get_x());
-        x->push();
-        delete x;
+      x=new CL_LuaValue(current_block->get_x());
+      x->push();
+      delete x;
     }
 }
 
@@ -508,13 +538,13 @@ static void block_get_x()
  */
 static void block_get_y()
 {
-    CL_LuaValue *y;
+  CL_LuaValue *y;
 
-    if (current_block!=NULL && block_read)
+  if (current_block!=NULL && block_read)
     {
-        y=new CL_LuaValue(current_block->get_y());
-        y->push();
-        delete y;
+      y=new CL_LuaValue(current_block->get_y());
+      y->push();
+      delete y;
     }
 }
 
@@ -525,13 +555,13 @@ static void block_get_y()
  */
 static void block_set_x()
 {
-    int x;
+  int x;
 
-    if (current_block!=NULL && block_write)
+  if (current_block!=NULL && block_write)
     {
-        x=CL_Lua::getparam(1);
+      x=CL_Lua::getparam(1);
 
-        current_block->set_x(x);
+      current_block->set_x(x);
     }
 }
 
@@ -542,13 +572,13 @@ static void block_set_x()
  */
 static void block_set_y()
 {
-    int y;
+  int y;
 
-    if (current_block!=NULL && block_write)
+  if (current_block!=NULL && block_write)
     {
-        y=CL_Lua::getparam(1);
+      y=CL_Lua::getparam(1);
 
-        current_block->set_y(y);
+      current_block->set_y(y);
     }
 }
 
@@ -559,15 +589,15 @@ static void block_set_y()
  */
 static void block_add_item()
 {
-    int type,x,y;
+  int type,x,y;
 
-    if (current_block!=NULL && block_write)
+  if (current_block!=NULL && block_write)
     {
-        x=CL_Lua::getparam(1);        
-        y=CL_Lua::getparam(2);        
-        type=CL_Lua::getparam(3);        
+      x=CL_Lua::getparam(1);        
+      y=CL_Lua::getparam(2);        
+      type=CL_Lua::getparam(3);        
 
-        current_block->add_item(x,y,type);
+      current_block->add_item(x,y,type);
     }
 }
 
@@ -578,13 +608,13 @@ static void block_add_item()
  */
 static void block_get_nb_items()
 {
-    CL_LuaValue *nb;
+  CL_LuaValue *nb;
 
-    if (current_block!=NULL && block_read)
+  if (current_block!=NULL && block_read)
     {
-        nb=new CL_LuaValue(current_block->get_nb_items());
-        nb->push();
-        delete nb;
+      nb=new CL_LuaValue(current_block->get_nb_items());
+      nb->push();
+      delete nb;
     }
 }
 
@@ -595,16 +625,16 @@ static void block_get_nb_items()
  */
 static void block_get_item_x()
 {
-    CL_LuaValue *x;
-    int i;
+  CL_LuaValue *x;
+  int i;
 
-    if (current_block!=NULL && block_read)
+  if (current_block!=NULL && block_read)
     {
-        i=CL_Lua::getparam(1);
+      i=CL_Lua::getparam(1);
 
-        x=new CL_LuaValue(current_block->get_item_x(i));
-        x->push();
-        delete x;
+      x=new CL_LuaValue(current_block->get_item_x(i));
+      x->push();
+      delete x;
     }
 }
 
@@ -615,16 +645,16 @@ static void block_get_item_x()
  */
 static void block_get_item_y()
 {
-    CL_LuaValue *y;
-    int i;
+  CL_LuaValue *y;
+  int i;
 
-    if (current_block!=NULL && block_read)
+  if (current_block!=NULL && block_read)
     {
-        i=CL_Lua::getparam(1);
+      i=CL_Lua::getparam(1);
 
-        y=new CL_LuaValue(current_block->get_item_y(i));
-        y->push();
-        delete y;
+      y=new CL_LuaValue(current_block->get_item_y(i));
+      y->push();
+      delete y;
     }
 }
 
@@ -635,16 +665,16 @@ static void block_get_item_y()
  */
 static void block_get_item_color()
 {
-    CL_LuaValue *color;
-    int i;
+  CL_LuaValue *color;
+  int i;
 
-    if (current_block!=NULL && block_read)
+  if (current_block!=NULL && block_read)
     {
-        i=CL_Lua::getparam(1);
+      i=CL_Lua::getparam(1);
 
-        color=new CL_LuaValue(current_block->get_item_color(i));
-        color->push();
-        delete color;
+      color=new CL_LuaValue(current_block->get_item_color(i));
+      color->push();
+      delete color;
     }
 }
 
@@ -655,14 +685,14 @@ static void block_get_item_color()
  */
 static void block_set_item_x()
 {
-    int i,x;
+  int i,x;
 
-    if (current_block!=NULL && block_write)
+  if (current_block!=NULL && block_write)
     {
-        i=CL_Lua::getparam(1);
-        x=CL_Lua::getparam(2);
+      i=CL_Lua::getparam(1);
+      x=CL_Lua::getparam(2);
 
-        current_block->set_item_x(i,x);
+      current_block->set_item_x(i,x);
     }
 }
 
@@ -673,14 +703,14 @@ static void block_set_item_x()
  */
 static void block_set_item_y()
 {
-    int i,y;
+  int i,y;
 
-    if (current_block!=NULL && block_write)
+  if (current_block!=NULL && block_write)
     {
-        i=CL_Lua::getparam(1);
-        y=CL_Lua::getparam(2);
+      i=CL_Lua::getparam(1);
+      y=CL_Lua::getparam(2);
 
-        current_block->set_item_y(i,y);
+      current_block->set_item_y(i,y);
     }
 }
 
@@ -691,14 +721,14 @@ static void block_set_item_y()
  */
 static void block_set_item_color()
 {
-    int i,color;
+  int i,color;
 
-    if (current_block!=NULL && block_write)
+  if (current_block!=NULL && block_write)
     {
-        i=CL_Lua::getparam(1);
-        color=CL_Lua::getparam(2);
+      i=CL_Lua::getparam(1);
+      color=CL_Lua::getparam(2);
 
-        current_block->set_item_color(i,color);
+      current_block->set_item_color(i,color);
     }
 }
 
@@ -709,13 +739,13 @@ static void block_set_item_color()
  */
 static void map_get_width()
 {
-    CL_LuaValue *width;
+  CL_LuaValue *width;
 
-    if (current_map!=NULL && map_read)
+  if (current_map!=NULL && map_read)
     {
-        width=new CL_LuaValue(U61_Map::WIDTH);
-        width->push();
-        delete width;
+      width=new CL_LuaValue(U61_Map::WIDTH);
+      width->push();
+      delete width;
     }
 }
 
@@ -726,13 +756,13 @@ static void map_get_width()
  */
 static void map_get_height()
 {
-    CL_LuaValue *height;
+  CL_LuaValue *height;
 
-    if (current_map!=NULL && map_read)
+  if (current_map!=NULL && map_read)
     {
-        height=new CL_LuaValue(U61_Map::HEIGHT);
-        height->push();
-        delete height;
+      height=new CL_LuaValue(U61_Map::HEIGHT);
+      height->push();
+      delete height;
     }
 }
 
@@ -743,17 +773,17 @@ static void map_get_height()
  */
 static void map_get_square_color()
 {
-    int x,y;
-    CL_LuaValue *color;
+  int x,y;
+  CL_LuaValue *color;
 
-    if (current_map!=NULL && map_read)
+  if (current_map!=NULL && map_read)
     {
-        x=CL_Lua::getparam(1);
-        y=CL_Lua::getparam(2);
+      x=CL_Lua::getparam(1);
+      y=CL_Lua::getparam(2);
 
-        color=new CL_LuaValue(current_map->get_square_color(x,y));
-        color->push();
-        delete color;
+      color=new CL_LuaValue(current_map->get_square_color(x,y));
+      color->push();
+      delete color;
     }
 }
 
@@ -764,15 +794,15 @@ static void map_get_square_color()
  */
 static void map_set_square_color()
 {
-    int x,y,color;
+  int x,y,color;
 
-    if (current_map!=NULL && map_write)
+  if (current_map!=NULL && map_write)
     {
-        x=CL_Lua::getparam(1);
-        y=CL_Lua::getparam(2);
-        color=CL_Lua::getparam(3);
+      x=CL_Lua::getparam(1);
+      y=CL_Lua::getparam(2);
+      color=CL_Lua::getparam(3);
 
-        current_map->set_square_color(x,y,color);
+      current_map->set_square_color(x,y,color);
     }
 }
 
@@ -783,13 +813,13 @@ static void map_set_square_color()
  */
 static void map_get_time()
 {
-    CL_LuaValue *score;
+  CL_LuaValue *score;
 
-    if (current_map!=NULL && map_read)
+  if (current_map!=NULL && map_read)
     {
-        score=new CL_LuaValue(current_map->get_time());
-        score->push();
-        delete score;
+      score=new CL_LuaValue(current_map->get_time());
+      score->push();
+      delete score;
     }
 }
 
@@ -800,13 +830,13 @@ static void map_get_time()
  */
 static void map_get_nb_games()
 {
-    CL_LuaValue *score;
+  CL_LuaValue *score;
 
-    if (current_map!=NULL && map_read)
+  if (current_map!=NULL && map_read)
     {
-        score=new CL_LuaValue(current_map->get_nb_games());
-        score->push();
-        delete score;
+      score=new CL_LuaValue(current_map->get_nb_games());
+      score->push();
+      delete score;
     }
 }
 
@@ -817,13 +847,13 @@ static void map_get_nb_games()
  */
 static void map_get_score()
 {
-    CL_LuaValue *score;
+  CL_LuaValue *score;
 
-    if (current_map!=NULL && map_read)
+  if (current_map!=NULL && map_read)
     {
-        score=new CL_LuaValue(current_map->get_score());
-        score->push();
-        delete score;
+      score=new CL_LuaValue(current_map->get_score());
+      score->push();
+      delete score;
     }
 }
 
@@ -834,13 +864,13 @@ static void map_get_score()
  */
 static void map_set_score()
 {
-    int score;
+  int score;
 
-    if (current_map!=NULL && map_write)
+  if (current_map!=NULL && map_write)
     {
-        score=CL_Lua::getparam(1);
+      score=CL_Lua::getparam(1);
 
-        current_map->set_score(score);
+      current_map->set_score(score);
     }
 }
 
@@ -851,13 +881,13 @@ static void map_set_score()
  */
 static void map_add_score()
 {
-    int score;
+  int score;
 
-    if (current_map!=NULL && map_write)
+  if (current_map!=NULL && map_write)
     {
-        score=CL_Lua::getparam(1);
+      score=CL_Lua::getparam(1);
 
-        current_map->add_score(score);
+      current_map->add_score(score);
     }
 }
 
@@ -868,15 +898,15 @@ static void map_add_score()
  */
 static void map_get_global()
 {
-    CL_LuaValue *glob;
-    int i;
+  CL_LuaValue *glob;
+  int i;
 
-    if (current_map!=NULL && map_read)
+  if (current_map!=NULL && map_read)
     {
-        i=CL_Lua::getparam(1);
-        glob=new CL_LuaValue(current_map->get_global(i));
-        glob->push();
-        delete glob;
+      i=CL_Lua::getparam(1);
+      glob=new CL_LuaValue(current_map->get_global(i));
+      glob->push();
+      delete glob;
     }
 }
 
@@ -887,14 +917,14 @@ static void map_get_global()
  */
 static void map_set_global()
 {
-    int i,glob;
+  int i,glob;
 
-    if (current_map!=NULL && map_write)
+  if (current_map!=NULL && map_write)
     {
-        i=CL_Lua::getparam(1);
-        glob=CL_Lua::getparam(2);
+      i=CL_Lua::getparam(1);
+      glob=CL_Lua::getparam(2);
 
-        current_map->set_global(i,glob);
+      current_map->set_global(i,glob);
     }
 }
 
@@ -905,13 +935,13 @@ static void map_set_global()
  */
 static void map_get_prevision_state()
 {
-    CL_LuaValue *state;
+  CL_LuaValue *state;
 
-    if (current_map!=NULL && map_read)
+  if (current_map!=NULL && map_read)
     {
-        state=new CL_LuaValue(current_map->get_prevision_state() ? 1 : 0);
-        state->push();
-        delete state;
+      state=new CL_LuaValue(current_map->get_prevision_state() ? 1 : 0);
+      state->push();
+      delete state;
     }
 }
 
@@ -922,13 +952,13 @@ static void map_get_prevision_state()
  */
 static void map_set_prevision_state()
 {
-    int state;
+  int state;
 
-    if (current_map!=NULL && map_write)
+  if (current_map!=NULL && map_write)
     {
-        state=CL_Lua::getparam(1);
+      state=CL_Lua::getparam(1);
 
-        current_map->set_prevision_state(state);
+      current_map->set_prevision_state(state);
     }
 }
 
@@ -939,13 +969,13 @@ static void map_set_prevision_state()
  */
 static void map_get_preview_state()
 {
-    CL_LuaValue *state;
+  CL_LuaValue *state;
 
-    if (current_map!=NULL && map_read)
+  if (current_map!=NULL && map_read)
     {
-        state=new CL_LuaValue(current_map->get_preview_state() ? 1 : 0);
-        state->push();
-        delete state;
+      state=new CL_LuaValue(current_map->get_preview_state() ? 1 : 0);
+      state->push();
+      delete state;
     }
 }
 
@@ -956,13 +986,53 @@ static void map_get_preview_state()
  */
 static void map_set_preview_state()
 {
-    int state;
+  int state;
 
-    if (current_map!=NULL && map_write)
+  if (current_map!=NULL && map_write)
     {
-        state=CL_Lua::getparam(1);
+      state=CL_Lua::getparam(1);
 
-        current_map->set_preview_state(state);
+      current_map->set_preview_state(state);
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Blows up a square, ie puts this square in a exploding state
+ */
+static void map_blow_up_square()
+{
+  int x,y;
+
+  if (current_map!=NULL && map_write)
+    {
+      x=CL_Lua::getparam(1);
+      y=CL_Lua::getparam(2);
+
+      current_map->blow_up_square(x,y);
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * this function is accessible from lua script 
+ * it returns != 0 if the square is exploding, and 0 otherwise
+ */
+static void map_is_square_exploding()
+{
+  int x,y;
+  CL_LuaValue *exploding;
+
+  if (current_map!=NULL && map_read)
+    {
+      x=CL_Lua::getparam(1);
+      y=CL_Lua::getparam(2);
+
+      exploding=new CL_LuaValue(
+				current_map->is_square_exploding(x,y)
+				? 1 :0);
+      exploding->push();
+      delete exploding;
     }
 }
 
@@ -972,35 +1042,37 @@ static void map_set_preview_state()
  */
 void U61_Script::record_all()
 {
-    CL_Lua::record(C_BLOCK_RESET,block_reset);
-    CL_Lua::record(C_BLOCK_CENTER,block_center);
-    CL_Lua::record(C_BLOCK_GET_X,block_get_x);
-    CL_Lua::record(C_BLOCK_GET_Y,block_get_y);
-    CL_Lua::record(C_BLOCK_SET_X,block_set_x);
-    CL_Lua::record(C_BLOCK_SET_Y,block_set_y);
-    CL_Lua::record(C_BLOCK_ADD_ITEM,block_add_item);
-    CL_Lua::record(C_BLOCK_GET_NB_ITEMS,block_get_nb_items);
-    CL_Lua::record(C_BLOCK_GET_ITEM_X,block_get_item_x);
-    CL_Lua::record(C_BLOCK_GET_ITEM_Y,block_get_item_y);
-    CL_Lua::record(C_BLOCK_GET_ITEM_COLOR,block_get_item_color);
-    CL_Lua::record(C_BLOCK_SET_ITEM_X,block_set_item_x);
-    CL_Lua::record(C_BLOCK_SET_ITEM_Y,block_set_item_y);
-    CL_Lua::record(C_BLOCK_SET_ITEM_COLOR,block_set_item_color);
-    CL_Lua::record(C_MAP_GET_WIDTH,map_get_width);
-    CL_Lua::record(C_MAP_GET_HEIGHT,map_get_height);
-    CL_Lua::record(C_MAP_GET_SQUARE_COLOR,map_get_square_color);
-    CL_Lua::record(C_MAP_SET_SQUARE_COLOR,map_set_square_color);
-    CL_Lua::record(C_MAP_GET_TIME,map_get_time);
-    CL_Lua::record(C_MAP_GET_NB_GAMES,map_get_nb_games);
-    CL_Lua::record(C_MAP_GET_SCORE,map_get_score);
-    CL_Lua::record(C_MAP_SET_SCORE,map_set_score);
-    CL_Lua::record(C_MAP_ADD_SCORE,map_add_score);
-    CL_Lua::record(C_MAP_GET_GLOBAL,map_get_global);
-    CL_Lua::record(C_MAP_SET_GLOBAL,map_set_global);
-    CL_Lua::record(C_MAP_GET_PREVISION_STATE,map_get_prevision_state);
-    CL_Lua::record(C_MAP_SET_PREVISION_STATE,map_set_prevision_state);
-    CL_Lua::record(C_MAP_GET_PREVIEW_STATE,map_get_preview_state);
-    CL_Lua::record(C_MAP_SET_PREVIEW_STATE,map_set_preview_state);
+  CL_Lua::record(C_BLOCK_RESET,block_reset);
+  CL_Lua::record(C_BLOCK_CENTER,block_center);
+  CL_Lua::record(C_BLOCK_GET_X,block_get_x);
+  CL_Lua::record(C_BLOCK_GET_Y,block_get_y);
+  CL_Lua::record(C_BLOCK_SET_X,block_set_x);
+  CL_Lua::record(C_BLOCK_SET_Y,block_set_y);
+  CL_Lua::record(C_BLOCK_ADD_ITEM,block_add_item);
+  CL_Lua::record(C_BLOCK_GET_NB_ITEMS,block_get_nb_items);
+  CL_Lua::record(C_BLOCK_GET_ITEM_X,block_get_item_x);
+  CL_Lua::record(C_BLOCK_GET_ITEM_Y,block_get_item_y);
+  CL_Lua::record(C_BLOCK_GET_ITEM_COLOR,block_get_item_color);
+  CL_Lua::record(C_BLOCK_SET_ITEM_X,block_set_item_x);
+  CL_Lua::record(C_BLOCK_SET_ITEM_Y,block_set_item_y);
+  CL_Lua::record(C_BLOCK_SET_ITEM_COLOR,block_set_item_color);
+  CL_Lua::record(C_MAP_GET_WIDTH,map_get_width);
+  CL_Lua::record(C_MAP_GET_HEIGHT,map_get_height);
+  CL_Lua::record(C_MAP_GET_SQUARE_COLOR,map_get_square_color);
+  CL_Lua::record(C_MAP_SET_SQUARE_COLOR,map_set_square_color);
+  CL_Lua::record(C_MAP_GET_TIME,map_get_time);
+  CL_Lua::record(C_MAP_GET_NB_GAMES,map_get_nb_games);
+  CL_Lua::record(C_MAP_GET_SCORE,map_get_score);
+  CL_Lua::record(C_MAP_SET_SCORE,map_set_score);
+  CL_Lua::record(C_MAP_ADD_SCORE,map_add_score);
+  CL_Lua::record(C_MAP_GET_GLOBAL,map_get_global);
+  CL_Lua::record(C_MAP_SET_GLOBAL,map_set_global);
+  CL_Lua::record(C_MAP_GET_PREVISION_STATE,map_get_prevision_state);
+  CL_Lua::record(C_MAP_SET_PREVISION_STATE,map_set_prevision_state);
+  CL_Lua::record(C_MAP_GET_PREVIEW_STATE,map_get_preview_state);
+  CL_Lua::record(C_MAP_SET_PREVIEW_STATE,map_set_preview_state);
+  CL_Lua::record(C_MAP_BLOW_UP_SQUARE,map_blow_up_square);
+  CL_Lua::record(C_MAP_IS_SQUARE_EXPLODING,map_is_square_exploding);
 }
 
 
