@@ -44,6 +44,7 @@
 #include "square.h"
 #include "global.h"
 #include "time.h"
+#include "utils.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -66,7 +67,7 @@ int U61_Square::cycle=0;
  */ 
 U61_Square::U61_Square()
 {
-    reset();
+  reset();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -84,9 +85,10 @@ U61_Square::~U61_Square()
  */ 
 void U61_Square::reset()
 {
-    color=0;
-    state=false;
-    cycle_offset=0;
+  color=0;
+  state=false;
+  cycle_offset=0;
+  exploding=false;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -95,7 +97,7 @@ void U61_Square::reset()
  */ 
 void U61_Square::enable()
 {
-    state=true;
+  state=true;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -104,7 +106,7 @@ void U61_Square::enable()
  */ 
 void U61_Square::disable()
 {
-    state=false;
+  state=false;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -113,7 +115,7 @@ void U61_Square::disable()
  */ 
 bool U61_Square::is_enabled()
 {
-    return state;
+  return state;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -122,7 +124,7 @@ bool U61_Square::is_enabled()
  */ 
 bool U61_Square::is_disabled()
 {
-    return !state;
+  return !state;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -131,13 +133,13 @@ bool U61_Square::is_disabled()
  */
 void U61_Square::set_color(int c)
 {
-    if (c>=0 && c<NB_COLORS)
+  if (c>=0 && c<NB_COLORS)
     {
-        color=c;
+      color=c;
     }
-    else
+  else
     {
-        color=0;
+      color=0;
     }
 }
 
@@ -147,7 +149,7 @@ void U61_Square::set_color(int c)
  */
 int U61_Square::get_color()
 {
-    return color;
+  return color;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -156,19 +158,108 @@ int U61_Square::get_color()
  */
 void U61_Square::update_cycle()
 {
-    cycle=(U61_Time::for_effect()/TIME_FACTOR)%NB_BITMAP;
+  cycle=(U61_Time::for_effect()/TIME_FACTOR)%NB_BITMAP;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * Starts an explosion. From now the square will return when questionned
+ * about if it's exploding or not, and it will be drawn with the
+ * explosion bitmap.
+ * It only leaves this state when the explosion is finished
+ */ 
+void U61_Square::begin_explosion()
+{
+  exploding=true;
+  explosion_counter=false;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * This function forces an explosion to end, generating an explosion_ended
+ * "event"
+ */
+void U61_Square::end_explosion()
+{
+  explosion_counter=EXPLOSION_LENGTH-1;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * An exploding square has to be updated at each game cycle, for the
+ * explosion to end when it's needed. It's a little tricky to manage
+ * since graphical animations are usually based on the for_effect()
+ * value, but here we want to use the for_logic() time.
+ * It is assumed that this function is called for each square
+ * at each game cycle.
+ */
+void U61_Square::update_explosion()
+{
+  if (exploding)
+    {  
+      explosion_counter++;
+      /*
+       * We test if the explosion is finished. A very important point
+       * is to test if explosion_counter is greater than
+       * EXPLOSION_LENGTH, and end the explosion if necessary.
+       * Indeed, there *must* be a game cycle when explosion_counter
+       * is equal to EXPLOSION_LENGTH-1 it's at this condition only
+       * that Lua scripts callbacks we'll be able to handle explosions
+       * in a correct manner.
+       */
+      if (explosion_counter>=EXPLOSION_LENGTH)
+	{
+	  exploding=false;
+	  explosion_counter=0;
+	}
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Returns true if the explosion is just ended. This condition should be
+ * checked for every square at every round, or one may miss the end
+ * of an explosion, and some Lua scripts can be based on such an event
+ */
+bool U61_Square::is_explosion_ended()
+{
+  /*
+   * We use EXPLOSION_LENGTH-1 as a test value, for we need this
+   * situation to happen once and only once, and a test with
+   * EXPLOSION_LENGTH would always return false (see update_explosion())
+   */
+  return explosion_counter==EXPLOSION_LENGTH-1;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Returns true if the square is exploding
+ */
+bool U61_Square::is_exploding()
+{
+  return exploding;
+}
+
+
 /*--------------------------------------------------------------------------*/
 /*
  * draws the square
  */
 void U61_Square::draw(int x, int y,int size)
 {
-    if (state)
+  if (state)
     {
-        U61_Global::data.square[color][size]->put_screen
-            (x,y,(cycle+cycle_offset)%NB_BITMAP);
+      if (!exploding)
+	{
+	  U61_Global::data.square[color][size]->put_screen
+	    (x,y,(cycle+cycle_offset)%NB_BITMAP);
+    
+	}
+      else
+	{
+	  U61_Global::data.explosion[size]->put_screen
+	    (x,y,(explosion_counter*NB_BITMAP)/EXPLOSION_LENGTH);
+	}
     }
 }
 
@@ -178,10 +269,10 @@ void U61_Square::draw(int x, int y,int size)
  */
 void U61_Square::draw_prevision(int x, int y,int size)
 {
-    if (state)
+  if (state)
     {
-        U61_Global::data.prevision[size]->put_screen
-            (x,y,(cycle+cycle_offset)%NB_BITMAP);
+      U61_Global::data.prevision[size]->put_screen
+	(x,y,(cycle+cycle_offset)%NB_BITMAP);
     }
 }
 
@@ -191,10 +282,10 @@ void U61_Square::draw_prevision(int x, int y,int size)
  */
 void U61_Square::draw_curse_bg(int x, int y,int size)
 {
-    if (state)
+  if (state)
     {
-        U61_Global::data.curse_bg[size]->put_screen
-            (x,y,(cycle+cycle_offset)%NB_BITMAP);
+      U61_Global::data.curse_bg[size]->put_screen
+	(x,y,(cycle+cycle_offset)%NB_BITMAP);
     }
 }
 
@@ -204,9 +295,9 @@ void U61_Square::draw_curse_bg(int x, int y,int size)
  */
 void U61_Square::draw_curse_fg(int x, int y,int size)
 {
-    if (state)
+  if (state)
     {
-        U61_Global::data.curse_fg[size]->put_screen
-            (x,y,(cycle+cycle_offset)%NB_BITMAP);
+      U61_Global::data.curse_fg[size]->put_screen
+	(x,y,(cycle+cycle_offset)%NB_BITMAP);
     }
 }
