@@ -55,37 +55,47 @@
 
 class U61_Square
 {
-public:
-    U61_Square();
-    ~U61_Square();
+ public:
+  U61_Square();
+  ~U61_Square();
     
-    void reset();
+  void reset();
     
-    void enable();
-    void disable();
-    bool is_enabled();
-    bool is_disabled();
+  void enable();
+  void disable();
+  bool is_enabled();
+  bool is_disabled();
 
-    void set_color(int c);
-    int get_color();
+  void set_color(int c);
+  int get_color();
 
-    static void update_cycle();
-    void draw(int x,int y, int size=U61_Data::SIZE_BIG);
-    void draw_prevision(int x,int y, int size=U61_Data::SIZE_BIG);
-    void draw_curse_fg(int x,int y, int size=U61_Data::SIZE_BIG);
-    void draw_curse_bg(int x,int y, int size=U61_Data::SIZE_BIG);
+  static void update_cycle();
+  void draw(int x,int y, int size=U61_Data::SIZE_BIG);
+  void draw_prevision(int x,int y, int size=U61_Data::SIZE_BIG);
+  void draw_curse_fg(int x,int y, int size=U61_Data::SIZE_BIG);
+  void draw_curse_bg(int x,int y, int size=U61_Data::SIZE_BIG);
 
-    const static int NB_COLORS=8;
+  void begin_explosion();
+  void end_explosion();
+  void update_explosion();
+  bool is_explosion_ended();
+  bool is_exploding();
     
-protected:
-    int cycle_offset;
-    int color;
-    bool state;
 
-    static int cycle;
+  const static int NB_COLORS=8;
     
-    const static int NB_BITMAP=16;
-    const static int TIME_FACTOR=3;
+ protected:
+  int cycle_offset;
+  int explosion_counter;
+  int color;
+  bool state;
+  bool exploding;
+
+  static int cycle;
+    
+  const static int EXPLOSION_LENGTH=33;
+  const static int NB_BITMAP=16;
+  const static int TIME_FACTOR=3;
 };
 
 #endif
