@@ -39,7 +39,6 @@
 
 #include "startmenu.h"
 #include "button.h"
-#include "toggle.h"
 #include "emptymenu.h"
 #include "pausingmenu.h"
 #include "joinmenu.h"
@@ -47,6 +46,7 @@
 #include "multiplayermenu.h"
 #include "networkmenu.h"
 #include "global.h"
+#include "activeplayermenu.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -62,22 +62,15 @@
  * creation of the start menu
  */ 
 U61_StartMenu::U61_StartMenu(U61_Menu *parent)
-    : U61_Menu(parent,"Choose a game type")
+  : U61_Menu(parent,"Choose a game type")
 {
-    add_item(new U61_Button("Play Alone"));
-    add_item(new U61_Button("Local Multiplayer Game"));
-    add_item(new U61_Button("New Network Game"));
-    add_item(new U61_Button("Join Network Game"));
-    add_item(new U61_Toggle("Player 1 is",
-        &(U61_Global::config.player[0].activable),"playing","disabled"));
-    add_item(new U61_Toggle("Player 2 is",
-        &(U61_Global::config.player[1].activable),"playing","disabled"));
-    add_item(new U61_Toggle("Player 3 is",
-        &(U61_Global::config.player[2].activable),"playing","disabled"));
-    add_item(new U61_Toggle("Player 4 is",
-        &(U61_Global::config.player[3].activable),"playing","disabled"));
+  add_item(new U61_Button("Play Alone"));
+  add_item(new U61_Button("Local Multiplayer Game"));
+  add_item(new U61_Button("New Network Game"));
+  add_item(new U61_Button("Join Network Game"));
+  add_item(new U61_Button("Choose players"));
 
-    select(0);
+  select(0);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -86,27 +79,31 @@ U61_StartMenu::U61_StartMenu(U61_Menu *parent)
  */
 U61_Menu *U61_StartMenu::validate()
 {
-    U61_Menu *next_menu;
+  U61_Menu *next_menu;
 
-    next_menu=this;
-    switch (selection)
+  next_menu=this;
+  switch (selection)
     {
     case 0:
-	next_menu=new U61_PausingMenu(new U61_AloneMenu(this));
-        U61_Global::game.start_local_alone();
-        break;
+      next_menu=new U61_PausingMenu(new U61_AloneMenu(this));
+      U61_Global::game.start_local_alone();
+      break;
     case 1:
-	next_menu=new U61_PausingMenu(new U61_MultiplayerMenu(this));
-        U61_Global::game.start_local_multiplayer();
-        break;
+      next_menu=new U61_PausingMenu(new U61_MultiplayerMenu(this));
+      U61_Global::game.start_local_multiplayer();
+      break;
     case 2:
-	next_menu=new U61_EmptyMenu(new U61_NetworkMenu(this));
-        U61_Global::game.start_network_new();
-        break;
+      next_menu=new U61_EmptyMenu(new U61_NetworkMenu(this));
+      U61_Global::game.start_network_new();
+      break;
     case 3:
-        next_menu=new U61_JoinMenu(this);
-        break;
+      next_menu=new U61_JoinMenu(this);
+      break;
+    case 4:
+      next_menu=new U61_ActivePlayerMenu(this);
+      break;
     }
 
-    return next_menu;
+  return next_menu;
 }
+
