@@ -87,6 +87,12 @@ int U61_Time::last_for_event;
  */
 int U61_Time::last_for_logic;
 
+/*--------------------------------------------------------------------------*/
+/*
+ * contains the last time when the display function has been called 
+ */
+int U61_Time::last_for_display;
+
 /*---------------------------------------------------------------------------
  functions
  ---------------------------------------------------------------------------*/
@@ -103,6 +109,7 @@ void U61_Time::reset(int time)
     paused=false;
     last_for_event=time;
     last_for_logic=time;
+    last_for_display=CL_System::get_time();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -218,7 +225,7 @@ bool U61_Time::is_logic_needed()
     /*
      * we calculate the time that would be returned by for_event,
      * except we don't use for_event since it performs useless
-     * and unwanted chechs, and we substract 1, so that logic is
+     * and unwanted checks, and we substract 1, so that logic is
      * always one tick behind events (safer)
      */ 
     time=system_time()-1;
@@ -246,6 +253,37 @@ void U61_Time::acknowledge_logic()
     last_for_logic++;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * returns true if a call to display() int the main game loop is needed
+ * The method is just to check if there's been enough time between the
+ * last call to display and now. If this time is too short, we should not
+ * display anything since it is quite useless.
+ */
+bool U61_Time::is_display_needed(int fps)
+{
+    bool result=false;
+    int time;
+
+    time=CL_System::get_time();
+    if (time-last_for_display>=1000/fps)
+      {
+	result=true;
+      }   
+
+    return result;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Tells the system that a display has been performed, this is necessary
+ * for is_display_needed to work correctly 
+ */
+void U61_Time::acknowledge_display()
+{
+    last_for_display=CL_System::get_time();
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * enters the paused state
@@ -308,4 +346,14 @@ int U61_Time::system_time()
     return (time-reset_offset-alter_offset-pause_offset)/TIME_UNIT;
 }
 
-
+/*--------------------------------------------------------------------------*/
+/*
+ * Let the CPU go idle for some time. This is usefull because sometimes
+ * there's no need for the game to get all the CPU usage. Therefore whenever
+ * we feel CPU is not needed, we go idle for some time
+ */
+void U61_Time::idle()
+{
+  CL_System::sleep(IDLE_DELAY);
+  //  cout<<"sleep "<<CL_System::get_time()<<"\n";
+}
